using System;
using System.Collections.Generic;
using RestSharp;
using Gustos.Api.Client;
using IO.Swagger.Model;

namespace IO.Swagger.Api
{
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public interface IAwardApi
    {
        /// <summary>
        /// Add new award to vintage Adds specified in _award_id_ parameter award to specified in _vintage_id_ parameter vintage. In case of success, returns nothing.  NOTE: Award cannot be edited. To edit vintage award it SHOULD be deleted and added again.  WARNING: Be careful wrong parameter _vintage_id_ can throw _insuficient_rights_ error.
        /// </summary>
        /// <param name="body"></param>
        /// <param name="vintageId">Identificator of vintage.</param>
        /// <param name="awardId">Identificator of award.</param>
        /// <returns></returns>
        void AddVintageAward (Award body, long? vintageId, long? awardId);
        /// <summary>
        /// Get information about award Gets information about award. Returning response body fields could be selected using _fields_ parameter. This method works without any authorization.
        /// </summary>
        /// <param name="awardId">Identificator of award.</param>
        /// <param name="fields">Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value.</param>
        /// <returns>Award</returns>
        Award GetAward (long? awardId, List<string> fields);
        /// <summary>
        /// List awards Searches awards by _name_. This method works without any authorization.
        /// </summary>
        /// <param name="competitionId">Identificator of competition.</param>
        /// <param name="name">Partial or full _name_ of the award to be searched.</param>
        /// <param name="fields">Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value.</param>
        /// <param name="offset">Specifies the number of objects to skip before server starts to return objects from the request query.</param>
        /// <param name="limit">Limits the objects returned in a response to a specified number of objects.</param>
        /// <param name="sort">Specifies a field on which to sort the response.</param>
        /// <param name="order">Specifies that the values in the specified field should be sorted in ascending or descending order. Takes effect only if _sort_ parameter defined.</param>
        /// <returns>AwardList</returns>
        AwardList ListCompetitionAwards (long? competitionId, string name, List<string> fields, long? offset, long? limit, string sort, string order);
        /// <summary>
        /// List vintage awards Searches awards by _name_, _competition_ and/or _year_ fields. This method works without any authorization.
        /// </summary>
        /// <param name="vintageId">Identificator of vintage.</param>
        /// <param name="name">Partial or full _name_ of the award to be searched.</param>
        /// <param name="competition">_Competition_ identificator where award was gained.</param>
        /// <param name="competitionName">Partial or full _name_ of the competition where award was gained. If _competition_ parameter is set this parameter will not take effect.</param>
        /// <param name="year">_Year_ when award was gained. This field can be _exact value_ or an [_interval_](https://en.wikipedia.org/wiki/Interval_(mathematics)).</param>
        /// <param name="fields">Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value.</param>
        /// <param name="offset">Specifies the number of objects to skip before server starts to return objects from the request query.</param>
        /// <param name="limit">Limits the objects returned in a response to a specified number of objects.</param>
        /// <param name="sort">Specifies a field on which to sort the response.</param>
        /// <param name="order">Specifies that the values in the specified field should be sorted in ascending or descending order. Takes effect only if _sort_ parameter defined.</param>
        /// <returns>AwardList</returns>
        AwardList ListVintageAwards (long? vintageId, string name, long? competition, string competitionName, string year, List<string> fields, long? offset, long? limit, string sort, string order);
        /// <summary>
        /// Remove award form vintage Removes specified in _award_id_ parameter award from specified in _vintage_id_ parameter vintage. In case of success, returns nothing.  NOTE: If body field _year_ is not specified, awards of any year will be removed.  WARNING: Be careful wrong parameter _vintage_id_ can throw _insuficient_rights_ error.
        /// </summary>
        /// <param name="body"></param>
        /// <param name="vintageId">Identificator of vintage.</param>
        /// <param name="awardId">Identificator of award.</param>
        /// <returns></returns>
        void RemoveVintageAward (Award body, long? vintageId, long? awardId);
    }
  
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public class AwardApi : IAwardApi
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="AwardApi"/> class.
        /// </summary>
        /// <param name="apiClient"> an instance of ApiClient (optional)</param>
        /// <returns></returns>
        public AwardApi(ApiClient apiClient = null)
        {
            if (apiClient == null) // use the default one in Configuration
                this.ApiClient = Configuration.DefaultApiClient; 
            else
                this.ApiClient = apiClient;
        }
    
        /// <summary>
        /// Initializes a new instance of the <see cref="AwardApi"/> class.
        /// </summary>
        /// <returns></returns>
        public AwardApi(String basePath)
        {
            this.ApiClient = new ApiClient(basePath);
        }
    
        /// <summary>
        /// Sets the base path of the API client.
        /// </summary>
        /// <param name="basePath">The base path</param>
        /// <value>The base path</value>
        public void SetBasePath(String basePath)
        {
            this.ApiClient.BasePath = basePath;
        }
    
        /// <summary>
        /// Gets the base path of the API client.
        /// </summary>
        /// <param name="basePath">The base path</param>
        /// <value>The base path</value>
        public String GetBasePath(String basePath)
        {
            return this.ApiClient.BasePath;
        }
    
        /// <summary>
        /// Gets or sets the API client.
        /// </summary>
        /// <value>An instance of the ApiClient</value>
        public ApiClient ApiClient {get; set;}
    
        /// <summary>
        /// Add new award to vintage Adds specified in _award_id_ parameter award to specified in _vintage_id_ parameter vintage. In case of success, returns nothing.  NOTE: Award cannot be edited. To edit vintage award it SHOULD be deleted and added again.  WARNING: Be careful wrong parameter _vintage_id_ can throw _insuficient_rights_ error.
        /// </summary>
        /// <param name="body"></param>
        /// <param name="vintageId">Identificator of vintage.</param>
        /// <param name="awardId">Identificator of award.</param>
        /// <returns></returns>
        public void AddVintageAward (Award body, long? vintageId, long? awardId)
        {
            // verify the required parameter 'body' is set
            if (body == null) throw new ApiException(400, "Missing required parameter 'body' when calling AddVintageAward");
            // verify the required parameter 'vintageId' is set
            if (vintageId == null) throw new ApiException(400, "Missing required parameter 'vintageId' when calling AddVintageAward");
            // verify the required parameter 'awardId' is set
            if (awardId == null) throw new ApiException(400, "Missing required parameter 'awardId' when calling AddVintageAward");
    
            var path = "/vintage/{vintage_id}/award/{award_id}";
            path = path.Replace("{format}", "json");
            path = path.Replace("{" + "vintage_id" + "}", ApiClient.ParameterToString(vintageId));
path = path.Replace("{" + "award_id" + "}", ApiClient.ParameterToString(awardId));
    
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
                                                postBody = ApiClient.Serialize(body); // http body (model) parameter
    
            // authentication setting, if any
            String[] authSettings = new String[] { "common" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.POST, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling AddVintageAward: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling AddVintageAward: " + response.ErrorMessage, response.ErrorMessage);
    
            return;
        }
    
        /// <summary>
        /// Get information about award Gets information about award. Returning response body fields could be selected using _fields_ parameter. This method works without any authorization.
        /// </summary>
        /// <param name="awardId">Identificator of award.</param>
        /// <param name="fields">Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value.</param>
        /// <returns>Award</returns>
        public Award GetAward (long? awardId, List<string> fields)
        {
            // verify the required parameter 'awardId' is set
            if (awardId == null) throw new ApiException(400, "Missing required parameter 'awardId' when calling GetAward");
    
            var path = "/award/{award_id}";
            path = path.Replace("{format}", "json");
            path = path.Replace("{" + "award_id" + "}", ApiClient.ParameterToString(awardId));
    
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (fields != null) queryParams.Add("fields", ApiClient.ParameterToString(fields)); // query parameter
                                        
            // authentication setting, if any
            String[] authSettings = new String[] {  };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling GetAward: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling GetAward: " + response.ErrorMessage, response.ErrorMessage);
    
            return (Award) ApiClient.Deserialize(response.Content, typeof(Award), response.Headers);
        }
    
        /// <summary>
        /// List awards Searches awards by _name_. This method works without any authorization.
        /// </summary>
        /// <param name="competitionId">Identificator of competition.</param>
        /// <param name="name">Partial or full _name_ of the award to be searched.</param>
        /// <param name="fields">Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value.</param>
        /// <param name="offset">Specifies the number of objects to skip before server starts to return objects from the request query.</param>
        /// <param name="limit">Limits the objects returned in a response to a specified number of objects.</param>
        /// <param name="sort">Specifies a field on which to sort the response.</param>
        /// <param name="order">Specifies that the values in the specified field should be sorted in ascending or descending order. Takes effect only if _sort_ parameter defined.</param>
        /// <returns>AwardList</returns>
        public AwardList ListCompetitionAwards (long? competitionId, string name, List<string> fields, long? offset, long? limit, string sort, string order)
        {
            // verify the required parameter 'competitionId' is set
            if (competitionId == null) throw new ApiException(400, "Missing required parameter 'competitionId' when calling ListCompetitionAwards");
    
            var path = "/competition/{competition_id}/award/list";
            path = path.Replace("{format}", "json");
            path = path.Replace("{" + "competition_id" + "}", ApiClient.ParameterToString(competitionId));
    
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (name != null) queryParams.Add("name", ApiClient.ParameterToString(name)); // query parameter
 if (fields != null) queryParams.Add("fields", ApiClient.ParameterToString(fields)); // query parameter
 if (offset != null) queryParams.Add("offset", ApiClient.ParameterToString(offset)); // query parameter
 if (limit != null) queryParams.Add("limit", ApiClient.ParameterToString(limit)); // query parameter
 if (sort != null) queryParams.Add("sort", ApiClient.ParameterToString(sort)); // query parameter
 if (order != null) queryParams.Add("order", ApiClient.ParameterToString(order)); // query parameter
                                        
            // authentication setting, if any
            String[] authSettings = new String[] {  };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling ListCompetitionAwards: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling ListCompetitionAwards: " + response.ErrorMessage, response.ErrorMessage);
    
            return (AwardList) ApiClient.Deserialize(response.Content, typeof(AwardList), response.Headers);
        }
    
        /// <summary>
        /// List vintage awards Searches awards by _name_, _competition_ and/or _year_ fields. This method works without any authorization.
        /// </summary>
        /// <param name="vintageId">Identificator of vintage.</param>
        /// <param name="name">Partial or full _name_ of the award to be searched.</param>
        /// <param name="competition">_Competition_ identificator where award was gained.</param>
        /// <param name="competitionName">Partial or full _name_ of the competition where award was gained. If _competition_ parameter is set this parameter will not take effect.</param>
        /// <param name="year">_Year_ when award was gained. This field can be _exact value_ or an [_interval_](https://en.wikipedia.org/wiki/Interval_(mathematics)).</param>
        /// <param name="fields">Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value.</param>
        /// <param name="offset">Specifies the number of objects to skip before server starts to return objects from the request query.</param>
        /// <param name="limit">Limits the objects returned in a response to a specified number of objects.</param>
        /// <param name="sort">Specifies a field on which to sort the response.</param>
        /// <param name="order">Specifies that the values in the specified field should be sorted in ascending or descending order. Takes effect only if _sort_ parameter defined.</param>
        /// <returns>AwardList</returns>
        public AwardList ListVintageAwards (long? vintageId, string name, long? competition, string competitionName, string year, List<string> fields, long? offset, long? limit, string sort, string order)
        {
            // verify the required parameter 'vintageId' is set
            if (vintageId == null) throw new ApiException(400, "Missing required parameter 'vintageId' when calling ListVintageAwards");
    
            var path = "/vintage/{vintage_id}/award/list";
            path = path.Replace("{format}", "json");
            path = path.Replace("{" + "vintage_id" + "}", ApiClient.ParameterToString(vintageId));
    
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (name != null) queryParams.Add("name", ApiClient.ParameterToString(name)); // query parameter
 if (competition != null) queryParams.Add("competition", ApiClient.ParameterToString(competition)); // query parameter
 if (competitionName != null) queryParams.Add("competition_name", ApiClient.ParameterToString(competitionName)); // query parameter
 if (year != null) queryParams.Add("year", ApiClient.ParameterToString(year)); // query parameter
 if (fields != null) queryParams.Add("fields", ApiClient.ParameterToString(fields)); // query parameter
 if (offset != null) queryParams.Add("offset", ApiClient.ParameterToString(offset)); // query parameter
 if (limit != null) queryParams.Add("limit", ApiClient.ParameterToString(limit)); // query parameter
 if (sort != null) queryParams.Add("sort", ApiClient.ParameterToString(sort)); // query parameter
 if (order != null) queryParams.Add("order", ApiClient.ParameterToString(order)); // query parameter
                                        
            // authentication setting, if any
            String[] authSettings = new String[] {  };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling ListVintageAwards: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling ListVintageAwards: " + response.ErrorMessage, response.ErrorMessage);
    
            return (AwardList) ApiClient.Deserialize(response.Content, typeof(AwardList), response.Headers);
        }
    
        /// <summary>
        /// Remove award form vintage Removes specified in _award_id_ parameter award from specified in _vintage_id_ parameter vintage. In case of success, returns nothing.  NOTE: If body field _year_ is not specified, awards of any year will be removed.  WARNING: Be careful wrong parameter _vintage_id_ can throw _insuficient_rights_ error.
        /// </summary>
        /// <param name="body"></param>
        /// <param name="vintageId">Identificator of vintage.</param>
        /// <param name="awardId">Identificator of award.</param>
        /// <returns></returns>
        public void RemoveVintageAward (Award body, long? vintageId, long? awardId)
        {
            // verify the required parameter 'body' is set
            if (body == null) throw new ApiException(400, "Missing required parameter 'body' when calling RemoveVintageAward");
            // verify the required parameter 'vintageId' is set
            if (vintageId == null) throw new ApiException(400, "Missing required parameter 'vintageId' when calling RemoveVintageAward");
            // verify the required parameter 'awardId' is set
            if (awardId == null) throw new ApiException(400, "Missing required parameter 'awardId' when calling RemoveVintageAward");
    
            var path = "/vintage/{vintage_id}/award/{award_id}";
            path = path.Replace("{format}", "json");
            path = path.Replace("{" + "vintage_id" + "}", ApiClient.ParameterToString(vintageId));
path = path.Replace("{" + "award_id" + "}", ApiClient.ParameterToString(awardId));
    
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
                                                postBody = ApiClient.Serialize(body); // http body (model) parameter
    
            // authentication setting, if any
            String[] authSettings = new String[] { "common" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.DELETE, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling RemoveVintageAward: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling RemoveVintageAward: " + response.ErrorMessage, response.ErrorMessage);
    
            return;
        }
    
    }
}
