using System;
using System.Collections.Generic;
using RestSharp;
using Gustos.Api.Client;
using IO.Swagger.Model;

namespace IO.Swagger.Api
{
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public interface ICompetitionApi
    {
        /// <summary>
        /// Get information about competition Gets information about competition. Returning response body fields could be selected using _fields_ parameter. This method works without any authorization.
        /// </summary>
        /// <param name="competitionId">Identificator of competition.</param>
        /// <param name="fields">Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value.</param>
        /// <returns>Competition</returns>
        Competition GetCompetition (long? competitionId, List<string> fields);
        /// <summary>
        /// List competitions Searches competitions by _name_, _country_, and/or _description_. This method works without any authorization.
        /// </summary>
        /// <param name="name">Partial or full _name_ of the competition to be searched.</param>
        /// <param name="country">Numerical value of _country_ (_tid_) of competitions to be displayed.</param>
        /// <param name="countryName">Partial or full _country_ name of the competition to be searched.</param>
        /// <param name="description">Partial or full _series_ competition description.</param>
        /// <param name="fields">Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value.</param>
        /// <param name="offset">Specifies the number of objects to skip before server starts to return objects from the request query.</param>
        /// <param name="limit">Limits the objects returned in a response to a specified number of objects.</param>
        /// <param name="sort">Specifies a field on which to sort the response.</param>
        /// <param name="order">Specifies that the values in the specified field should be sorted in ascending or descending order. Takes effect only if _sort_ parameter defined.</param>
        /// <returns>CompetitionList</returns>
        CompetitionList ListCompetitions (string name, long? country, string countryName, string description, List<string> fields, long? offset, long? limit, string sort, string order);
    }
  
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public class CompetitionApi : ICompetitionApi
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="CompetitionApi"/> class.
        /// </summary>
        /// <param name="apiClient"> an instance of ApiClient (optional)</param>
        /// <returns></returns>
        public CompetitionApi(ApiClient apiClient = null)
        {
            if (apiClient == null) // use the default one in Configuration
                this.ApiClient = Configuration.DefaultApiClient; 
            else
                this.ApiClient = apiClient;
        }
    
        /// <summary>
        /// Initializes a new instance of the <see cref="CompetitionApi"/> class.
        /// </summary>
        /// <returns></returns>
        public CompetitionApi(String basePath)
        {
            this.ApiClient = new ApiClient(basePath);
        }
    
        /// <summary>
        /// Sets the base path of the API client.
        /// </summary>
        /// <param name="basePath">The base path</param>
        /// <value>The base path</value>
        public void SetBasePath(String basePath)
        {
            this.ApiClient.BasePath = basePath;
        }
    
        /// <summary>
        /// Gets the base path of the API client.
        /// </summary>
        /// <param name="basePath">The base path</param>
        /// <value>The base path</value>
        public String GetBasePath(String basePath)
        {
            return this.ApiClient.BasePath;
        }
    
        /// <summary>
        /// Gets or sets the API client.
        /// </summary>
        /// <value>An instance of the ApiClient</value>
        public ApiClient ApiClient {get; set;}
    
        /// <summary>
        /// Get information about competition Gets information about competition. Returning response body fields could be selected using _fields_ parameter. This method works without any authorization.
        /// </summary>
        /// <param name="competitionId">Identificator of competition.</param>
        /// <param name="fields">Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value.</param>
        /// <returns>Competition</returns>
        public Competition GetCompetition (long? competitionId, List<string> fields)
        {
            // verify the required parameter 'competitionId' is set
            if (competitionId == null) throw new ApiException(400, "Missing required parameter 'competitionId' when calling GetCompetition");
    
            var path = "/competition/{competition_id}";
            path = path.Replace("{format}", "json");
            path = path.Replace("{" + "competition_id" + "}", ApiClient.ParameterToString(competitionId));
    
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (fields != null) queryParams.Add("fields", ApiClient.ParameterToString(fields)); // query parameter
                                        
            // authentication setting, if any
            String[] authSettings = new String[] {  };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling GetCompetition: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling GetCompetition: " + response.ErrorMessage, response.ErrorMessage);
    
            return (Competition) ApiClient.Deserialize(response.Content, typeof(Competition), response.Headers);
        }
    
        /// <summary>
        /// List competitions Searches competitions by _name_, _country_, and/or _description_. This method works without any authorization.
        /// </summary>
        /// <param name="name">Partial or full _name_ of the competition to be searched.</param>
        /// <param name="country">Numerical value of _country_ (_tid_) of competitions to be displayed.</param>
        /// <param name="countryName">Partial or full _country_ name of the competition to be searched.</param>
        /// <param name="description">Partial or full _series_ competition description.</param>
        /// <param name="fields">Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value.</param>
        /// <param name="offset">Specifies the number of objects to skip before server starts to return objects from the request query.</param>
        /// <param name="limit">Limits the objects returned in a response to a specified number of objects.</param>
        /// <param name="sort">Specifies a field on which to sort the response.</param>
        /// <param name="order">Specifies that the values in the specified field should be sorted in ascending or descending order. Takes effect only if _sort_ parameter defined.</param>
        /// <returns>CompetitionList</returns>
        public CompetitionList ListCompetitions (string name, long? country, string countryName, string description, List<string> fields, long? offset, long? limit, string sort, string order)
        {
    
            var path = "/competition/list";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (name != null) queryParams.Add("name", ApiClient.ParameterToString(name)); // query parameter
 if (country != null) queryParams.Add("country", ApiClient.ParameterToString(country)); // query parameter
 if (countryName != null) queryParams.Add("country_name", ApiClient.ParameterToString(countryName)); // query parameter
 if (description != null) queryParams.Add("description", ApiClient.ParameterToString(description)); // query parameter
 if (fields != null) queryParams.Add("fields", ApiClient.ParameterToString(fields)); // query parameter
 if (offset != null) queryParams.Add("offset", ApiClient.ParameterToString(offset)); // query parameter
 if (limit != null) queryParams.Add("limit", ApiClient.ParameterToString(limit)); // query parameter
 if (sort != null) queryParams.Add("sort", ApiClient.ParameterToString(sort)); // query parameter
 if (order != null) queryParams.Add("order", ApiClient.ParameterToString(order)); // query parameter
                                        
            // authentication setting, if any
            String[] authSettings = new String[] {  };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling ListCompetitions: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling ListCompetitions: " + response.ErrorMessage, response.ErrorMessage);
    
            return (CompetitionList) ApiClient.Deserialize(response.Content, typeof(CompetitionList), response.Headers);
        }
    
    }
}
