using System;
using System.Collections.Generic;
using RestSharp;
using Gustos.Api.Client;
using IO.Swagger.Model;

namespace IO.Swagger.Api
{
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public interface ISeriaApi
    {
        /// <summary>
        /// Create new wine seria Creates new wine seria. Created wine seria will be owned by specified in _vineyard_id_ winery.  WARNING: Be careful wrong parameter _vineyard_id_ can throw _insuficient_rights_ error.
        /// </summary>
        /// <param name="body"></param>
        /// <param name="vineyardId">Identificator of winery.</param>
        /// <returns>Seria</returns>
        Seria CreateSeria (Seria body, long? vineyardId);
        /// <summary>
        /// List wine series Searches owned by specified winery wine series by name field. This method works without any authorization.
        /// </summary>
        /// <param name="vineyardId">Identificator of winery.</param>
        /// <param name="name">Partial or full name of series to be searched.</param>
        /// <param name="fields">Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value.</param>
        /// <param name="offset">Specifies the number of objects to skip before server starts to return objects from the request query.</param>
        /// <param name="limit">Limits the objects returned in a response to a specified number of objects.</param>
        /// <param name="sort">Specifies a field on which to sort the response.</param>
        /// <param name="order">Specifies that the values in the specified field should be sorted in ascending or descending order. Takes effect only if _sort_ parameter defined.</param>
        /// <returns>SeriaList</returns>
        SeriaList ListSeries (long? vineyardId, string name, List<string> fields, long? offset, long? limit, string sort, string order);
    }
  
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public class SeriaApi : ISeriaApi
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="SeriaApi"/> class.
        /// </summary>
        /// <param name="apiClient"> an instance of ApiClient (optional)</param>
        /// <returns></returns>
        public SeriaApi(ApiClient apiClient = null)
        {
            if (apiClient == null) // use the default one in Configuration
                this.ApiClient = Configuration.DefaultApiClient; 
            else
                this.ApiClient = apiClient;
        }
    
        /// <summary>
        /// Initializes a new instance of the <see cref="SeriaApi"/> class.
        /// </summary>
        /// <returns></returns>
        public SeriaApi(String basePath)
        {
            this.ApiClient = new ApiClient(basePath);
        }
    
        /// <summary>
        /// Sets the base path of the API client.
        /// </summary>
        /// <param name="basePath">The base path</param>
        /// <value>The base path</value>
        public void SetBasePath(String basePath)
        {
            this.ApiClient.BasePath = basePath;
        }
    
        /// <summary>
        /// Gets the base path of the API client.
        /// </summary>
        /// <param name="basePath">The base path</param>
        /// <value>The base path</value>
        public String GetBasePath(String basePath)
        {
            return this.ApiClient.BasePath;
        }
    
        /// <summary>
        /// Gets or sets the API client.
        /// </summary>
        /// <value>An instance of the ApiClient</value>
        public ApiClient ApiClient {get; set;}
    
        /// <summary>
        /// Create new wine seria Creates new wine seria. Created wine seria will be owned by specified in _vineyard_id_ winery.  WARNING: Be careful wrong parameter _vineyard_id_ can throw _insuficient_rights_ error.
        /// </summary>
        /// <param name="body"></param>
        /// <param name="vineyardId">Identificator of winery.</param>
        /// <returns>Seria</returns>
        public Seria CreateSeria (Seria body, long? vineyardId)
        {
            // verify the required parameter 'body' is set
            if (body == null) throw new ApiException(400, "Missing required parameter 'body' when calling CreateSeria");
            // verify the required parameter 'vineyardId' is set
            if (vineyardId == null) throw new ApiException(400, "Missing required parameter 'vineyardId' when calling CreateSeria");
    
            var path = "/vineyard/{vineyard_id}/seria";
            path = path.Replace("{format}", "json");
            path = path.Replace("{" + "vineyard_id" + "}", ApiClient.ParameterToString(vineyardId));
    
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
                                                postBody = ApiClient.Serialize(body); // http body (model) parameter
    
            // authentication setting, if any
            String[] authSettings = new String[] { "common" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.POST, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling CreateSeria: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling CreateSeria: " + response.ErrorMessage, response.ErrorMessage);
    
            return (Seria) ApiClient.Deserialize(response.Content, typeof(Seria), response.Headers);
        }
    
        /// <summary>
        /// List wine series Searches owned by specified winery wine series by name field. This method works without any authorization.
        /// </summary>
        /// <param name="vineyardId">Identificator of winery.</param>
        /// <param name="name">Partial or full name of series to be searched.</param>
        /// <param name="fields">Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value.</param>
        /// <param name="offset">Specifies the number of objects to skip before server starts to return objects from the request query.</param>
        /// <param name="limit">Limits the objects returned in a response to a specified number of objects.</param>
        /// <param name="sort">Specifies a field on which to sort the response.</param>
        /// <param name="order">Specifies that the values in the specified field should be sorted in ascending or descending order. Takes effect only if _sort_ parameter defined.</param>
        /// <returns>SeriaList</returns>
        public SeriaList ListSeries (long? vineyardId, string name, List<string> fields, long? offset, long? limit, string sort, string order)
        {
            // verify the required parameter 'vineyardId' is set
            if (vineyardId == null) throw new ApiException(400, "Missing required parameter 'vineyardId' when calling ListSeries");
    
            var path = "/vineyard/{vineyard_id}/seria/list";
            path = path.Replace("{format}", "json");
            path = path.Replace("{" + "vineyard_id" + "}", ApiClient.ParameterToString(vineyardId));
    
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (name != null) queryParams.Add("name", ApiClient.ParameterToString(name)); // query parameter
 if (fields != null) queryParams.Add("fields", ApiClient.ParameterToString(fields)); // query parameter
 if (offset != null) queryParams.Add("offset", ApiClient.ParameterToString(offset)); // query parameter
 if (limit != null) queryParams.Add("limit", ApiClient.ParameterToString(limit)); // query parameter
 if (sort != null) queryParams.Add("sort", ApiClient.ParameterToString(sort)); // query parameter
 if (order != null) queryParams.Add("order", ApiClient.ParameterToString(order)); // query parameter
                                        
            // authentication setting, if any
            String[] authSettings = new String[] {  };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling ListSeries: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling ListSeries: " + response.ErrorMessage, response.ErrorMessage);
    
            return (SeriaList) ApiClient.Deserialize(response.Content, typeof(SeriaList), response.Headers);
        }
    
    }
}
