using System;
using System.Collections.Generic;
using RestSharp;
using Gustos.Api.Client;
using IO.Swagger.Model;

namespace IO.Swagger.Api
{
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public interface ITaxonomyApi
    {
        /// <summary>
        /// Create new taxonomy term Creates new taxonomy term in specified in _vocabulary_id_ vocabulary. Adding new terms is allowed for _region_ vocabulary only.  WARNING: Be careful wrong parameter _vocabulary_id_ can throw _insuficient_rights_ error.
        /// </summary>
        /// <param name="body"></param>
        /// <param name="vocabularyId">Vocabulary _vid_ or _machine name_.</param>
        /// <returns>Term</returns>
        Term CreateTerm (Term body, string vocabularyId);
        /// <summary>
        /// List taxonomy terms Gets information about vocabulary and its terms by specified in _vocabulary_id_ identificator. This method works without any authorization.
        /// </summary>
        /// <param name="vocabularyId">Vocabulary _vid_ or _machine name_.</param>
        /// <returns>Vocabulary</returns>
        Vocabulary ListTerms (string vocabularyId);
    }
  
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public class TaxonomyApi : ITaxonomyApi
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="TaxonomyApi"/> class.
        /// </summary>
        /// <param name="apiClient"> an instance of ApiClient (optional)</param>
        /// <returns></returns>
        public TaxonomyApi(ApiClient apiClient = null)
        {
            if (apiClient == null) // use the default one in Configuration
                this.ApiClient = Configuration.DefaultApiClient; 
            else
                this.ApiClient = apiClient;
        }
    
        /// <summary>
        /// Initializes a new instance of the <see cref="TaxonomyApi"/> class.
        /// </summary>
        /// <returns></returns>
        public TaxonomyApi(String basePath)
        {
            this.ApiClient = new ApiClient(basePath);
        }
    
        /// <summary>
        /// Sets the base path of the API client.
        /// </summary>
        /// <param name="basePath">The base path</param>
        /// <value>The base path</value>
        public void SetBasePath(String basePath)
        {
            this.ApiClient.BasePath = basePath;
        }
    
        /// <summary>
        /// Gets the base path of the API client.
        /// </summary>
        /// <param name="basePath">The base path</param>
        /// <value>The base path</value>
        public String GetBasePath(String basePath)
        {
            return this.ApiClient.BasePath;
        }
    
        /// <summary>
        /// Gets or sets the API client.
        /// </summary>
        /// <value>An instance of the ApiClient</value>
        public ApiClient ApiClient {get; set;}
    
        /// <summary>
        /// Create new taxonomy term Creates new taxonomy term in specified in _vocabulary_id_ vocabulary. Adding new terms is allowed for _region_ vocabulary only.  WARNING: Be careful wrong parameter _vocabulary_id_ can throw _insuficient_rights_ error.
        /// </summary>
        /// <param name="body"></param>
        /// <param name="vocabularyId">Vocabulary _vid_ or _machine name_.</param>
        /// <returns>Term</returns>
        public Term CreateTerm (Term body, string vocabularyId)
        {
            // verify the required parameter 'body' is set
            if (body == null) throw new ApiException(400, "Missing required parameter 'body' when calling CreateTerm");
            // verify the required parameter 'vocabularyId' is set
            if (vocabularyId == null) throw new ApiException(400, "Missing required parameter 'vocabularyId' when calling CreateTerm");
    
            var path = "/taxonomy/{vocabulary_id}/term";
            path = path.Replace("{format}", "json");
            path = path.Replace("{" + "vocabulary_id" + "}", ApiClient.ParameterToString(vocabularyId));
    
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
                                                postBody = ApiClient.Serialize(body); // http body (model) parameter
    
            // authentication setting, if any
            String[] authSettings = new String[] { "common" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.POST, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling CreateTerm: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling CreateTerm: " + response.ErrorMessage, response.ErrorMessage);
    
            return (Term) ApiClient.Deserialize(response.Content, typeof(Term), response.Headers);
        }
    
        /// <summary>
        /// List taxonomy terms Gets information about vocabulary and its terms by specified in _vocabulary_id_ identificator. This method works without any authorization.
        /// </summary>
        /// <param name="vocabularyId">Vocabulary _vid_ or _machine name_.</param>
        /// <returns>Vocabulary</returns>
        public Vocabulary ListTerms (string vocabularyId)
        {
            // verify the required parameter 'vocabularyId' is set
            if (vocabularyId == null) throw new ApiException(400, "Missing required parameter 'vocabularyId' when calling ListTerms");
    
            var path = "/taxonomy/{vocabulary_id}/term/list";
            path = path.Replace("{format}", "json");
            path = path.Replace("{" + "vocabulary_id" + "}", ApiClient.ParameterToString(vocabularyId));
    
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
                                                    
            // authentication setting, if any
            String[] authSettings = new String[] {  };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling ListTerms: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling ListTerms: " + response.ErrorMessage, response.ErrorMessage);
    
            return (Vocabulary) ApiClient.Deserialize(response.Content, typeof(Vocabulary), response.Headers);
        }
    
    }
}
