using System;
using System.Collections.Generic;
using RestSharp;
using Gustos.Api.Client;
using IO.Swagger.Model;

namespace IO.Swagger.Api
{
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public interface IVineyardApi
    {
        /// <summary>
        /// Create new winery Creates request for register new winery in the system.  Note: this method creates only __request__ to winery add. Winery will be created after checking by the moderator.
        /// </summary>
        /// <param name="body">_Name_ and _email_ fields MUST be unique.</param>
        /// <returns></returns>
        void CreateVineyard (Body body);
        /// <summary>
        /// Get information about winery Gets information about winery. Returning response body fields could be selected using _fields_ parameter. This method works without any authorization.
        /// </summary>
        /// <param name="vineyardId">Identificator of winery.</param>
        /// <param name="fields">Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value.</param>
        /// <returns>Vineyard</returns>
        Vineyard GetVineyard (long? vineyardId, List<string> fields);
        /// <summary>
        /// List wineries Searches winery by _name_, _description_, _region_ and/or _country_ names. This method works without any authorization.
        /// </summary>
        /// <param name="name">Partial or full _name_ of the winery to be searched.</param>
        /// <param name="description">Partial or full _description_ text of the winery to be searched.</param>
        /// <param name="region">Partial or full _region_ name of the winery to be searched.</param>
        /// <param name="country">Numerical value of _country_ of the wineries to be displayed.</param>
        /// <param name="countryName">Partial or full _country_ name of the winery to be searched.</param>
        /// <param name="hasAwards">Defines if wines of displayed vineyards must contain awards.</param>
        /// <param name="fields">Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value.</param>
        /// <param name="offset">Specifies the number of objects to skip before server starts to return objects from the request query.</param>
        /// <param name="limit">Limits the objects returned in a response to a specified number of objects.</param>
        /// <param name="sort">Specifies a field on which to sort the response.</param>
        /// <param name="order">Specifies that the values in the specified field should be sorted in ascending or descending order. Takes effect only if _sort_ parameter defined.</param>
        /// <returns>VineyardList</returns>
        VineyardList ListVineyards (string name, string description, string region, long? country, string countryName, bool? hasAwards, List<string> fields, long? offset, long? limit, string sort, string order);
        /// <summary>
        /// Update information about winery Updates information about winery. In case of success, returns actual information about winery. Returning response body fields could be selected using _fields_ parameter.  WARNING: Be careful wrong parameter _vineyard_id_ can throw _insuficient_rights_ error.
        /// </summary>
        /// <param name="vineyardId">Identificator of winery.</param>
        /// <param name="body">Request body __SHOULD__ contain only fields with new values. _Fields_ parameter __SHOULD__ contain same fields as request body.

///WARNING: Be careful wrong parameter can throw _insuficient_rights_ error.</param>
        /// <param name="fields">Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value.</param>
        /// <returns>Vineyard</returns>
        Vineyard UpdateVineyard (long? vineyardId, Vineyard body, List<string> fields);
    }
  
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public class VineyardApi : IVineyardApi
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="VineyardApi"/> class.
        /// </summary>
        /// <param name="apiClient"> an instance of ApiClient (optional)</param>
        /// <returns></returns>
        public VineyardApi(ApiClient apiClient = null)
        {
            if (apiClient == null) // use the default one in Configuration
                this.ApiClient = Configuration.DefaultApiClient; 
            else
                this.ApiClient = apiClient;
        }
    
        /// <summary>
        /// Initializes a new instance of the <see cref="VineyardApi"/> class.
        /// </summary>
        /// <returns></returns>
        public VineyardApi(String basePath)
        {
            this.ApiClient = new ApiClient(basePath);
        }
    
        /// <summary>
        /// Sets the base path of the API client.
        /// </summary>
        /// <param name="basePath">The base path</param>
        /// <value>The base path</value>
        public void SetBasePath(String basePath)
        {
            this.ApiClient.BasePath = basePath;
        }
    
        /// <summary>
        /// Gets the base path of the API client.
        /// </summary>
        /// <param name="basePath">The base path</param>
        /// <value>The base path</value>
        public String GetBasePath(String basePath)
        {
            return this.ApiClient.BasePath;
        }
    
        /// <summary>
        /// Gets or sets the API client.
        /// </summary>
        /// <value>An instance of the ApiClient</value>
        public ApiClient ApiClient {get; set;}
    
        /// <summary>
        /// Create new winery Creates request for register new winery in the system.  Note: this method creates only __request__ to winery add. Winery will be created after checking by the moderator.
        /// </summary>
        /// <param name="body">_Name_ and _email_ fields MUST be unique.</param>
        /// <returns></returns>
        public void CreateVineyard (Body body)
        {
            // verify the required parameter 'body' is set
            if (body == null) throw new ApiException(400, "Missing required parameter 'body' when calling CreateVineyard");
    
            var path = "/vineyard";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
                                                postBody = ApiClient.Serialize(body); // http body (model) parameter
    
            // authentication setting, if any
            String[] authSettings = new String[] { "common" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.POST, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling CreateVineyard: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling CreateVineyard: " + response.ErrorMessage, response.ErrorMessage);
    
            return;
        }
    
        /// <summary>
        /// Get information about winery Gets information about winery. Returning response body fields could be selected using _fields_ parameter. This method works without any authorization.
        /// </summary>
        /// <param name="vineyardId">Identificator of winery.</param>
        /// <param name="fields">Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value.</param>
        /// <returns>Vineyard</returns>
        public Vineyard GetVineyard (long? vineyardId, List<string> fields)
        {
            // verify the required parameter 'vineyardId' is set
            if (vineyardId == null) throw new ApiException(400, "Missing required parameter 'vineyardId' when calling GetVineyard");
    
            var path = "/vineyard/{vineyard_id}";
            path = path.Replace("{format}", "json");
            path = path.Replace("{" + "vineyard_id" + "}", ApiClient.ParameterToString(vineyardId));
    
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (fields != null) queryParams.Add("fields", ApiClient.ParameterToString(fields)); // query parameter
                                        
            // authentication setting, if any
            String[] authSettings = new String[] {  };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling GetVineyard: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling GetVineyard: " + response.ErrorMessage, response.ErrorMessage);
    
            return (Vineyard) ApiClient.Deserialize(response.Content, typeof(Vineyard), response.Headers);
        }
    
        /// <summary>
        /// List wineries Searches winery by _name_, _description_, _region_ and/or _country_ names. This method works without any authorization.
        /// </summary>
        /// <param name="name">Partial or full _name_ of the winery to be searched.</param>
        /// <param name="description">Partial or full _description_ text of the winery to be searched.</param>
        /// <param name="region">Partial or full _region_ name of the winery to be searched.</param>
        /// <param name="country">Numerical value of _country_ of the wineries to be displayed.</param>
        /// <param name="countryName">Partial or full _country_ name of the winery to be searched.</param>
        /// <param name="hasAwards">Defines if wines of displayed vineyards must contain awards.</param>
        /// <param name="fields">Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value.</param>
        /// <param name="offset">Specifies the number of objects to skip before server starts to return objects from the request query.</param>
        /// <param name="limit">Limits the objects returned in a response to a specified number of objects.</param>
        /// <param name="sort">Specifies a field on which to sort the response.</param>
        /// <param name="order">Specifies that the values in the specified field should be sorted in ascending or descending order. Takes effect only if _sort_ parameter defined.</param>
        /// <returns>VineyardList</returns>
        public VineyardList ListVineyards (string name, string description, string region, long? country, string countryName, bool? hasAwards, List<string> fields, long? offset, long? limit, string sort, string order)
        {
    
            var path = "/vineyard/list";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (name != null) queryParams.Add("name", ApiClient.ParameterToString(name)); // query parameter
 if (description != null) queryParams.Add("description", ApiClient.ParameterToString(description)); // query parameter
 if (region != null) queryParams.Add("region", ApiClient.ParameterToString(region)); // query parameter
 if (country != null) queryParams.Add("country", ApiClient.ParameterToString(country)); // query parameter
 if (countryName != null) queryParams.Add("country_name", ApiClient.ParameterToString(countryName)); // query parameter
 if (hasAwards != null) queryParams.Add("has_awards", ApiClient.ParameterToString(hasAwards)); // query parameter
 if (fields != null) queryParams.Add("fields", ApiClient.ParameterToString(fields)); // query parameter
 if (offset != null) queryParams.Add("offset", ApiClient.ParameterToString(offset)); // query parameter
 if (limit != null) queryParams.Add("limit", ApiClient.ParameterToString(limit)); // query parameter
 if (sort != null) queryParams.Add("sort", ApiClient.ParameterToString(sort)); // query parameter
 if (order != null) queryParams.Add("order", ApiClient.ParameterToString(order)); // query parameter
                                        
            // authentication setting, if any
            String[] authSettings = new String[] {  };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling ListVineyards: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling ListVineyards: " + response.ErrorMessage, response.ErrorMessage);
    
            return (VineyardList) ApiClient.Deserialize(response.Content, typeof(VineyardList), response.Headers);
        }
    
        /// <summary>
        /// Update information about winery Updates information about winery. In case of success, returns actual information about winery. Returning response body fields could be selected using _fields_ parameter.  WARNING: Be careful wrong parameter _vineyard_id_ can throw _insuficient_rights_ error.
        /// </summary>
        /// <param name="vineyardId">Identificator of winery.</param>
        /// <param name="body">Request body __SHOULD__ contain only fields with new values. _Fields_ parameter __SHOULD__ contain same fields as request body.

///WARNING: Be careful wrong parameter can throw _insuficient_rights_ error.</param>
        /// <param name="fields">Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value.</param>
        /// <returns>Vineyard</returns>
        public Vineyard UpdateVineyard (long? vineyardId, Vineyard body, List<string> fields)
        {
            // verify the required parameter 'vineyardId' is set
            if (vineyardId == null) throw new ApiException(400, "Missing required parameter 'vineyardId' when calling UpdateVineyard");
    
            var path = "/vineyard/{vineyard_id}";
            path = path.Replace("{format}", "json");
            path = path.Replace("{" + "vineyard_id" + "}", ApiClient.ParameterToString(vineyardId));
    
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (fields != null) queryParams.Add("fields", ApiClient.ParameterToString(fields)); // query parameter
                                    postBody = ApiClient.Serialize(body); // http body (model) parameter
    
            // authentication setting, if any
            String[] authSettings = new String[] { "common" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.PUT, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling UpdateVineyard: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling UpdateVineyard: " + response.ErrorMessage, response.ErrorMessage);
    
            return (Vineyard) ApiClient.Deserialize(response.Content, typeof(Vineyard), response.Headers);
        }
    
    }
}
