using System;
using System.Collections.Generic;
using RestSharp;
using Gustos.Api.Client;
using IO.Swagger.Model;

namespace IO.Swagger.Api
{
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public interface IVintageApi
    {
        /// <summary>
        /// Create new vintage Adds vintage to specified in _wine_id_ parameter wine. In case of success, returns actual information about added vintage. Returning response body fields could be selected using _fields_ parameter.  WARNING: Be careful wrong parameter _wine_id_ can throw _insuficient_rights_ error.
        /// </summary>
        /// <param name="body"></param>
        /// <param name="wineId">Identificator of wine.</param>
        /// <param name="fields">Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value.</param>
        /// <returns>Vintage</returns>
        Vintage CreateVintage (Vintage body, long? wineId, List<string> fields);
        /// <summary>
        /// Get information about vintage Gets information about vintage. Returning response body fields could be selected using _fields_ parameter. This method works without any authorization.
        /// </summary>
        /// <param name="vintageId">Identificator of vintage.</param>
        /// <param name="fields">Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value.</param>
        /// <returns>Vintage</returns>
        Vintage GetVintage (long? vintageId, List<string> fields);
        /// <summary>
        /// List vintages Gets list of all vintages of specified in _wine_id_ parameter wine. Returning objects could be filtered by _is_igp_, _stage_of_production_ and/or _region_ fields values. This method works without any authorization.
        /// </summary>
        /// <param name="wineId">Identificator of wine.</param>
        /// <param name="year">_Year_ of vintages to be returned. This field can be _exact value_ or an [_interval_](https://en.wikipedia.org/wiki/Interval_(mathematics)).</param>
        /// <param name="hasAwards">Defines if displayed wines must contain awards.</param>
        /// <param name="alcohol">Value of _alcohol_ amount of vintages to be displayed. This field can be _exact value_ or an [_interval_](https://en.wikipedia.org/wiki/Interval_(mathematics)).</param>
        /// <param name="sugar">Value of _sugar_ amount of vintages to be displayed. This field can be _exact value_ or an [_interval_](https://en.wikipedia.org/wiki/Interval_(mathematics)).</param>
        /// <param name="region">Numerical value (_tid_) of _region_ of vintages to be displayed.</param>
        /// <param name="regionName">Full or partial name of _region_ of vintages to be displayed. If _region_ parameter is set this parameter will not take effect.</param>
        /// <param name="isIgp">Value of _isIGP_ of vintages to be displayed.</param>
        /// <param name="grapes">Separated by space numerical values (_tid_) of _grapes_ included in vintages to be displayed.</param>
        /// <param name="fields">Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value.</param>
        /// <param name="offset">Specifies the number of objects to skip before server starts to return objects from the request query.</param>
        /// <param name="limit">Limits the objects returned in a response to a specified number of objects.</param>
        /// <param name="sort">Specifies a field on which to sort the response.</param>
        /// <param name="order">Specifies that the values in the specified field should be sorted in ascending or descending order. Takes effect only if _sort_ parameter defined.</param>
        /// <returns>VintageList</returns>
        VintageList ListVintages (long? wineId, string year, bool? hasAwards, string alcohol, string sugar, long? region, string regionName, bool? isIgp, List<long?> grapes, List<string> fields, long? offset, long? limit, string sort, string order);
        /// <summary>
        /// Update information about vintage123 Updates information about vintage. In case of success, returns actual information about updated vintage. Returning response body fields could be selected using _fields_ parameter.  WARNING: Be careful wrong parameter _vineyard_id_ can throw _insuficient_rights_ error.
        /// </summary>
        /// <param name="body">Request body __SHOULD__ contain only fields with new values. _Fields_ parameter __SHOULD__ contain same fields as request body.</param>
        /// <param name="vintageId">Identificator of vintage.</param>
        /// <param name="fields">Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value.</param>
        /// <returns>Vintage</returns>
        Vintage UpdateVintage (Vintage body, long? vintageId, List<string> fields);
    }
  
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public class VintageApi : IVintageApi
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="VintageApi"/> class.
        /// </summary>
        /// <param name="apiClient"> an instance of ApiClient (optional)</param>
        /// <returns></returns>
        public VintageApi(ApiClient apiClient = null)
        {
            if (apiClient == null) // use the default one in Configuration
                this.ApiClient = Configuration.DefaultApiClient; 
            else
                this.ApiClient = apiClient;
        }
    
        /// <summary>
        /// Initializes a new instance of the <see cref="VintageApi"/> class.
        /// </summary>
        /// <returns></returns>
        public VintageApi(String basePath)
        {
            this.ApiClient = new ApiClient(basePath);
        }
    
        /// <summary>
        /// Sets the base path of the API client.
        /// </summary>
        /// <param name="basePath">The base path</param>
        /// <value>The base path</value>
        public void SetBasePath(String basePath)
        {
            this.ApiClient.BasePath = basePath;
        }
    
        /// <summary>
        /// Gets the base path of the API client.
        /// </summary>
        /// <param name="basePath">The base path</param>
        /// <value>The base path</value>
        public String GetBasePath(String basePath)
        {
            return this.ApiClient.BasePath;
        }
    
        /// <summary>
        /// Gets or sets the API client.
        /// </summary>
        /// <value>An instance of the ApiClient</value>
        public ApiClient ApiClient {get; set;}
    
        /// <summary>
        /// Create new vintage Adds vintage to specified in _wine_id_ parameter wine. In case of success, returns actual information about added vintage. Returning response body fields could be selected using _fields_ parameter.  WARNING: Be careful wrong parameter _wine_id_ can throw _insuficient_rights_ error.
        /// </summary>
        /// <param name="body"></param>
        /// <param name="wineId">Identificator of wine.</param>
        /// <param name="fields">Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value.</param>
        /// <returns>Vintage</returns>
        public Vintage CreateVintage (Vintage body, long? wineId, List<string> fields)
        {
            // verify the required parameter 'body' is set
            if (body == null) throw new ApiException(400, "Missing required parameter 'body' when calling CreateVintage");
            // verify the required parameter 'wineId' is set
            if (wineId == null) throw new ApiException(400, "Missing required parameter 'wineId' when calling CreateVintage");
    
            var path = "/wine/{wine_id}/vintage";
            path = path.Replace("{format}", "json");
            path = path.Replace("{" + "wine_id" + "}", ApiClient.ParameterToString(wineId));
    
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (fields != null) queryParams.Add("fields", ApiClient.ParameterToString(fields)); // query parameter
                                    postBody = ApiClient.Serialize(body); // http body (model) parameter
    
            // authentication setting, if any
            String[] authSettings = new String[] { "common" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.POST, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling CreateVintage: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling CreateVintage: " + response.ErrorMessage, response.ErrorMessage);
    
            return (Vintage) ApiClient.Deserialize(response.Content, typeof(Vintage), response.Headers);
        }
    
        /// <summary>
        /// Get information about vintage Gets information about vintage. Returning response body fields could be selected using _fields_ parameter. This method works without any authorization.
        /// </summary>
        /// <param name="vintageId">Identificator of vintage.</param>
        /// <param name="fields">Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value.</param>
        /// <returns>Vintage</returns>
        public Vintage GetVintage (long? vintageId, List<string> fields)
        {
            // verify the required parameter 'vintageId' is set
            if (vintageId == null) throw new ApiException(400, "Missing required parameter 'vintageId' when calling GetVintage");
    
            var path = "/vintage/{vintage_id}";
            path = path.Replace("{format}", "json");
            path = path.Replace("{" + "vintage_id" + "}", ApiClient.ParameterToString(vintageId));
    
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (fields != null) queryParams.Add("fields", ApiClient.ParameterToString(fields)); // query parameter
                                        
            // authentication setting, if any
            String[] authSettings = new String[] {  };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling GetVintage: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling GetVintage: " + response.ErrorMessage, response.ErrorMessage);
    
            return (Vintage) ApiClient.Deserialize(response.Content, typeof(Vintage), response.Headers);
        }
    
        /// <summary>
        /// List vintages Gets list of all vintages of specified in _wine_id_ parameter wine. Returning objects could be filtered by _is_igp_, _stage_of_production_ and/or _region_ fields values. This method works without any authorization.
        /// </summary>
        /// <param name="wineId">Identificator of wine.</param>
        /// <param name="year">_Year_ of vintages to be returned. This field can be _exact value_ or an [_interval_](https://en.wikipedia.org/wiki/Interval_(mathematics)).</param>
        /// <param name="hasAwards">Defines if displayed wines must contain awards.</param>
        /// <param name="alcohol">Value of _alcohol_ amount of vintages to be displayed. This field can be _exact value_ or an [_interval_](https://en.wikipedia.org/wiki/Interval_(mathematics)).</param>
        /// <param name="sugar">Value of _sugar_ amount of vintages to be displayed. This field can be _exact value_ or an [_interval_](https://en.wikipedia.org/wiki/Interval_(mathematics)).</param>
        /// <param name="region">Numerical value (_tid_) of _region_ of vintages to be displayed.</param>
        /// <param name="regionName">Full or partial name of _region_ of vintages to be displayed. If _region_ parameter is set this parameter will not take effect.</param>
        /// <param name="isIgp">Value of _isIGP_ of vintages to be displayed.</param>
        /// <param name="grapes">Separated by space numerical values (_tid_) of _grapes_ included in vintages to be displayed.</param>
        /// <param name="fields">Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value.</param>
        /// <param name="offset">Specifies the number of objects to skip before server starts to return objects from the request query.</param>
        /// <param name="limit">Limits the objects returned in a response to a specified number of objects.</param>
        /// <param name="sort">Specifies a field on which to sort the response.</param>
        /// <param name="order">Specifies that the values in the specified field should be sorted in ascending or descending order. Takes effect only if _sort_ parameter defined.</param>
        /// <returns>VintageList</returns>
        public VintageList ListVintages (long? wineId, string year, bool? hasAwards, string alcohol, string sugar, long? region, string regionName, bool? isIgp, List<long?> grapes, List<string> fields, long? offset, long? limit, string sort, string order)
        {
            // verify the required parameter 'wineId' is set
            if (wineId == null) throw new ApiException(400, "Missing required parameter 'wineId' when calling ListVintages");
    
            var path = "/wine/{wine_id}/vintage/list";
            path = path.Replace("{format}", "json");
            path = path.Replace("{" + "wine_id" + "}", ApiClient.ParameterToString(wineId));
    
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (year != null) queryParams.Add("year", ApiClient.ParameterToString(year)); // query parameter
 if (hasAwards != null) queryParams.Add("has_awards", ApiClient.ParameterToString(hasAwards)); // query parameter
 if (alcohol != null) queryParams.Add("alcohol", ApiClient.ParameterToString(alcohol)); // query parameter
 if (sugar != null) queryParams.Add("sugar", ApiClient.ParameterToString(sugar)); // query parameter
 if (region != null) queryParams.Add("region", ApiClient.ParameterToString(region)); // query parameter
 if (regionName != null) queryParams.Add("region_name", ApiClient.ParameterToString(regionName)); // query parameter
 if (isIgp != null) queryParams.Add("is_igp", ApiClient.ParameterToString(isIgp)); // query parameter
 if (grapes != null) queryParams.Add("grapes", ApiClient.ParameterToString(grapes)); // query parameter
 if (fields != null) queryParams.Add("fields", ApiClient.ParameterToString(fields)); // query parameter
 if (offset != null) queryParams.Add("offset", ApiClient.ParameterToString(offset)); // query parameter
 if (limit != null) queryParams.Add("limit", ApiClient.ParameterToString(limit)); // query parameter
 if (sort != null) queryParams.Add("sort", ApiClient.ParameterToString(sort)); // query parameter
 if (order != null) queryParams.Add("order", ApiClient.ParameterToString(order)); // query parameter
                                        
            // authentication setting, if any
            String[] authSettings = new String[] {  };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling ListVintages: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling ListVintages: " + response.ErrorMessage, response.ErrorMessage);
    
            return (VintageList) ApiClient.Deserialize(response.Content, typeof(VintageList), response.Headers);
        }
    
        /// <summary>
        /// Update information about vintage123 Updates information about vintage. In case of success, returns actual information about updated vintage. Returning response body fields could be selected using _fields_ parameter.  WARNING: Be careful wrong parameter _vineyard_id_ can throw _insuficient_rights_ error.
        /// </summary>
        /// <param name="body">Request body __SHOULD__ contain only fields with new values. _Fields_ parameter __SHOULD__ contain same fields as request body.</param>
        /// <param name="vintageId">Identificator of vintage.</param>
        /// <param name="fields">Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value.</param>
        /// <returns>Vintage</returns>
        public Vintage UpdateVintage (Vintage body, long? vintageId, List<string> fields)
        {
            // verify the required parameter 'body' is set
            if (body == null) throw new ApiException(400, "Missing required parameter 'body' when calling UpdateVintage");
            // verify the required parameter 'vintageId' is set
            if (vintageId == null) throw new ApiException(400, "Missing required parameter 'vintageId' when calling UpdateVintage");
    
            var path = "/vintage/{vintage_id}";
            path = path.Replace("{format}", "json");
            path = path.Replace("{" + "vintage_id" + "}", ApiClient.ParameterToString(vintageId));
    
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (fields != null) queryParams.Add("fields", ApiClient.ParameterToString(fields)); // query parameter
                                    postBody = ApiClient.Serialize(body); // http body (model) parameter
    
            // authentication setting, if any
            String[] authSettings = new String[] { "common" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.PUT, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling UpdateVintage: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling UpdateVintage: " + response.ErrorMessage, response.ErrorMessage);
    
            return (Vintage) ApiClient.Deserialize(response.Content, typeof(Vintage), response.Headers);
        }
    
    }
}
