using System;
using System.Collections.Generic;
using RestSharp;
using Gustos.Api.Client;
using IO.Swagger.Model;

namespace IO.Swagger.Api
{
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public interface IWineApi
    {
        /// <summary>
        /// Create new wine Creates wine and its vintage owned by specified in _vineyard_id_ parameter winery. In case of success, returns actual information about created wine.  - If beverage type is __wine__, request SHOULD contain _color_ and _co2_ values, otherwise it SHOULD contain _beverageTypeSecondary_ field.  - If __wine__&#x27;s _color_ is white, request SHOULD contain _grapeCategory_ value.  - If amount of co2 in __wine__ is less than 0.5 bar, request SHOULD contain _isExtraSweet_ and _isUnderFilmOfYeast_ fields, but if more than 2.5 bar - _method_ field.  Returning response body fields could be selected using _fields_ parameter.  WARNING: Be careful wrong parameter _vineyard_id_ can throw _insuficient_rights_ error.
        /// </summary>
        /// <param name="body"></param>
        /// <param name="vineyardId">Identificator of winery.</param>
        /// <param name="fields">Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value.</param>
        /// <returns>Wine</returns>
        Wine CreateWine (WineCreate body, long? vineyardId, List<string> fields);
        /// <summary>
        /// Get information about wine Gets information about wine. Returning response body fields could be selected using _fields_ parameter. This method works without any authorization.
        /// </summary>
        /// <param name="wineId">Identificator of wine.</param>
        /// <param name="fields">Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value.</param>
        /// <returns>Wine</returns>
        Wine GetWine (long? wineId, List<string> fields);
        /// <summary>
        /// List wines Searches wines owned by specified in _vineyard_id_ parameter winery by _name_, _country_, and/or _series_ names. This method works without any authorization.
        /// </summary>
        /// <param name="vineyardId">Identificator of winery.</param>
        /// <param name="name">Partial or full _name_ of the wine to be searched.</param>
        /// <param name="country">Numerical value of _country_ of wines to be displayed.</param>
        /// <param name="countryName">Partial or full _country_ name of the wine to be searched. If _country_ parameter is set this parameter will not take effect.</param>
        /// <param name="series">Numerical value of _series_ of wines to be displayed.</param>
        /// <param name="seriesName">Partial or full _series_ name of the wine to be searched. If _series_ parameter is set this parameter will not take effect.</param>
        /// <param name="year">_Year_ of vintages of wines to be returned. This field can be _exact value_ or an [_interval_](https://en.wikipedia.org/wiki/Interval_(mathematics)).</param>
        /// <param name="beverageType">Numerical value of primary _beverage type_ of wines to be displayed. Represents identificator of taxonomy term in _beverage_type_ taxonomy vocabulary without parents.  NOTE: See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description.</param>
        /// <param name="beverageTypeSecondary">Numerical value of secondary _beverage type_ of wines to be displayed. Represents identificator of taxonomy term in _beverage_type_ taxonomy vocabulary with parents.  NOTE: This field depends on _beverage_type_ field. See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description.</param>
        /// <param name="color">Numerical value of _color_ of wines to be displayed. Represents identificator of taxonomy term in _wine_color_ taxonomy vocabulary.  NOTE: Presence of this field in response depends on the _beverageType_ value. See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description.</param>
        /// <param name="grapeCategory">Value of _grape category_ field of wines to be displayed.  NOTE: Presence of this field in response depends on the _color_ value. See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description.</param>
        /// <param name="co2">Numerical value of _co2_ of wines to be displayed. Represents identificator of taxonomy term in _co2_ taxonomy vocabulary.  NOTE: Presence of this field in response depends on the _beverageType_ value. See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description.</param>
        /// <param name="method">Numerical value of _method_ of wines to be displayed. Represents identificator of taxonomy term in _method_ taxonomy vocabulary.  NOTE: Presence of this field in response depends on the _color_ value. See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description.</param>
        /// <param name="isExtraSweet">Value of _isExtraSweet_ field of wines to be displayed.  NOTE: Presence of this field in response depends on the _co2_ value. See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description.</param>
        /// <param name="isUnderFilmOfYeast">Value of _isUnderFilmOfYeast_ field of wines to be displayed.  NOTE: Presence of this field in response depends on the _co2_ value. See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description.</param>
        /// <param name="hasAwards">Defines if displayed wines must contain awards.</param>
        /// <param name="alcohol">Value of _alcohol_ amount of vintages of wines to be returned. This field can be _exact value_ or an [_interval_](https://en.wikipedia.org/wiki/Interval_(mathematics)).</param>
        /// <param name="sugar">Value of _sugar_ amount of vintages of wines to be returned. This field can be _exact value_ or an [_interval_](https://en.wikipedia.org/wiki/Interval_(mathematics)).</param>
        /// <param name="region">Numerical value (_tid_) of _region_ of wines to be displayed.</param>
        /// <param name="regionName">Full or partial name of _region_ of wines to be displayed. If _region_ parameter is set this parameter will not take effect.</param>
        /// <param name="isIgp">Value of _isIGP_ of wines to be displayed.</param>
        /// <param name="grapes">Separated by space numerical values (_tid_) of _grapes_ included in wines to be displayed.</param>
        /// <param name="fields">Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value.</param>
        /// <param name="offset">Specifies the number of objects to skip before server starts to return objects from the request query.</param>
        /// <param name="limit">Limits the objects returned in a response to a specified number of objects.</param>
        /// <param name="sort">Specifies a field on which to sort the response.</param>
        /// <param name="order">Specifies that the values in the specified field should be sorted in ascending or descending order. Takes effect only if _sort_ parameter defined.</param>
        /// <returns>WineList</returns>
        WineList ListVineyardWines (long? vineyardId, string name, long? country, string countryName, long? series, string seriesName, string year, long? beverageType, long? beverageTypeSecondary, long? color, string grapeCategory, long? co2, long? method, string isExtraSweet, string isUnderFilmOfYeast, bool? hasAwards, string alcohol, string sugar, long? region, string regionName, bool? isIgp, List<long?> grapes, List<string> fields, long? offset, long? limit, string sort, string order);
        /// <summary>
        /// List wines Searches wines by _name_, _country_, and/or _series_ names. This method works without any authorization.
        /// </summary>
        /// <param name="name">Partial or full _name_ of the wine to be searched.</param>
        /// <param name="country">Numerical value of _country_ of wines to be displayed.</param>
        /// <param name="countryName">Partial or full _country_ name of the wine to be searched. If _country_ parameter is set this parameter will not take effect.</param>
        /// <param name="series">Numerical value of _series_ of wines to be displayed.</param>
        /// <param name="seriesName">Partial or full _series_ name of the wine to be searched. If _series_ parameter is set this parameter will not take effect.</param>
        /// <param name="year">_Year_ of vintages of wines to be returned. This field can be _exact value_ or an [_interval_](https://en.wikipedia.org/wiki/Interval_(mathematics)).</param>
        /// <param name="beverageType">Numerical value of primary _beverage type_ of wines to be displayed. Represents identificator of taxonomy term in _beverage_type_ taxonomy vocabulary without parents.  NOTE: See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description.</param>
        /// <param name="beverageTypeSecondary">Numerical value of secondary _beverage type_ of wines to be displayed. Represents identificator of taxonomy term in _beverage_type_ taxonomy vocabulary with parents.  NOTE: This field depends on _beverage_type_ field. See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description.</param>
        /// <param name="color">Numerical value of _color_ of wines to be displayed. Represents identificator of taxonomy term in _wine_color_ taxonomy vocabulary.  NOTE: Presence of this field in response depends on the _beverageType_ value. See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description.</param>
        /// <param name="grapeCategory">Value of _grape category_ field of wines to be displayed.  NOTE: Presence of this field in response depends on the _color_ value. See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description.</param>
        /// <param name="co2">Numerical value of _co2_ of wines to be displayed. Represents identificator of taxonomy term in _co2_ taxonomy vocabulary.  NOTE: Presence of this field in response depends on the _beverageType_ value. See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description.</param>
        /// <param name="method">Numerical value of _method_ of wines to be displayed. Represents identificator of taxonomy term in _method_ taxonomy vocabulary.  NOTE: Presence of this field in response depends on the _color_ value. See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description.</param>
        /// <param name="isExtraSweet">Value of _isExtraSweet_ field of wines to be displayed.  NOTE: Presence of this field in response depends on the _co2_ value. See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description.</param>
        /// <param name="isUnderFilmOfYeast">Value of _isUnderFilmOfYeast_ field of wines to be displayed.  NOTE: Presence of this field in response depends on the _co2_ value. See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description.</param>
        /// <param name="hasAwards">Defines if displayed wines must contain awards.</param>
        /// <param name="alcohol">Value of _alcohol_ amount of vintages of wines to be returned. This field can be _exact value_ or an [_interval_](https://en.wikipedia.org/wiki/Interval_(mathematics)).</param>
        /// <param name="sugar">Value of _sugar_ amount of vintages of wines to be returned. This field can be _exact value_ or an [_interval_](https://en.wikipedia.org/wiki/Interval_(mathematics)).</param>
        /// <param name="region">Numerical value (_tid_) of _region_ of wines to be displayed.</param>
        /// <param name="regionName">Full or partial name of _region_ of wines to be displayed. If _region_ parameter is set this parameter will not take effect.</param>
        /// <param name="isIgp">Value of _isIGP_ of wines to be displayed.</param>
        /// <param name="grapes">Separated by space numerical values (_tid_) of _grapes_ included in wines to be displayed.</param>
        /// <param name="fields">Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value.</param>
        /// <param name="offset">Specifies the number of objects to skip before server starts to return objects from the request query.</param>
        /// <param name="limit">Limits the objects returned in a response to a specified number of objects.</param>
        /// <param name="sort">Specifies a field on which to sort the response.</param>
        /// <param name="order">Specifies that the values in the specified field should be sorted in ascending or descending order. Takes effect only if _sort_ parameter defined.</param>
        /// <returns>WineList</returns>
        WineList ListWines (string name, long? country, string countryName, long? series, string seriesName, string year, long? beverageType, long? beverageTypeSecondary, long? color, string grapeCategory, long? co2, long? method, string isExtraSweet, string isUnderFilmOfYeast, bool? hasAwards, string alcohol, string sugar, long? region, string regionName, bool? isIgp, List<long?> grapes, List<string> fields, long? offset, long? limit, string sort, string order);
        /// <summary>
        /// Update information about wine Updates information about beverage. In case of success, returns actual information about updated beverage.  - If beverage type is __wine__, request SHOULD contain _color_ and _co2_ values, otherwise it MUST contain _beverageTypeSecondary_ field.  - If __wine__&#x27;s _color_ is white, request MUST contain _grapeCategory_ value.  - If amount of co2 in __wine__ is less than 0.5 bar, request MUST contain _isExtraSweet_ and _isUnderFilmOfYeast_ fields, but if more than 2.5 bar - _method_ field.  Returning response body fields could be selected using _fields_ parameter.  WARNING: Be careful wrong parameter _wine_id_ can throw _insuficient_rights_ error.
        /// </summary>
        /// <param name="wineId">Identificator of wine.</param>
        /// <param name="body">Request body __SHOULD__ contain only fields with new values. _Fields_ parameter __SHOULD__ contain same fields as request body.</param>
        /// <param name="fields">Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value.</param>
        /// <returns>Wine</returns>
        Wine UpdateWine (long? wineId, Wine body, List<string> fields);
    }
  
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public class WineApi : IWineApi
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="WineApi"/> class.
        /// </summary>
        /// <param name="apiClient"> an instance of ApiClient (optional)</param>
        /// <returns></returns>
        public WineApi(ApiClient apiClient = null)
        {
            if (apiClient == null) // use the default one in Configuration
                this.ApiClient = Configuration.DefaultApiClient; 
            else
                this.ApiClient = apiClient;
        }
    
        /// <summary>
        /// Initializes a new instance of the <see cref="WineApi"/> class.
        /// </summary>
        /// <returns></returns>
        public WineApi(String basePath)
        {
            this.ApiClient = new ApiClient(basePath);
        }
    
        /// <summary>
        /// Sets the base path of the API client.
        /// </summary>
        /// <param name="basePath">The base path</param>
        /// <value>The base path</value>
        public void SetBasePath(String basePath)
        {
            this.ApiClient.BasePath = basePath;
        }
    
        /// <summary>
        /// Gets the base path of the API client.
        /// </summary>
        /// <param name="basePath">The base path</param>
        /// <value>The base path</value>
        public String GetBasePath(String basePath)
        {
            return this.ApiClient.BasePath;
        }
    
        /// <summary>
        /// Gets or sets the API client.
        /// </summary>
        /// <value>An instance of the ApiClient</value>
        public ApiClient ApiClient {get; set;}
    
        /// <summary>
        /// Create new wine Creates wine and its vintage owned by specified in _vineyard_id_ parameter winery. In case of success, returns actual information about created wine.  - If beverage type is __wine__, request SHOULD contain _color_ and _co2_ values, otherwise it SHOULD contain _beverageTypeSecondary_ field.  - If __wine__&#x27;s _color_ is white, request SHOULD contain _grapeCategory_ value.  - If amount of co2 in __wine__ is less than 0.5 bar, request SHOULD contain _isExtraSweet_ and _isUnderFilmOfYeast_ fields, but if more than 2.5 bar - _method_ field.  Returning response body fields could be selected using _fields_ parameter.  WARNING: Be careful wrong parameter _vineyard_id_ can throw _insuficient_rights_ error.
        /// </summary>
        /// <param name="body"></param>
        /// <param name="vineyardId">Identificator of winery.</param>
        /// <param name="fields">Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value.</param>
        /// <returns>Wine</returns>
        public Wine CreateWine (WineCreate body, long? vineyardId, List<string> fields)
        {
            // verify the required parameter 'body' is set
            if (body == null) throw new ApiException(400, "Missing required parameter 'body' when calling CreateWine");
            // verify the required parameter 'vineyardId' is set
            if (vineyardId == null) throw new ApiException(400, "Missing required parameter 'vineyardId' when calling CreateWine");
    
            var path = "/vineyard/{vineyard_id}/wine";
            path = path.Replace("{format}", "json");
            path = path.Replace("{" + "vineyard_id" + "}", ApiClient.ParameterToString(vineyardId));
    
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (fields != null) queryParams.Add("fields", ApiClient.ParameterToString(fields)); // query parameter
                                    postBody = ApiClient.Serialize(body); // http body (model) parameter
    
            // authentication setting, if any
            String[] authSettings = new String[] { "common" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.POST, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling CreateWine: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling CreateWine: " + response.ErrorMessage, response.ErrorMessage);
    
            return (Wine) ApiClient.Deserialize(response.Content, typeof(Wine), response.Headers);
        }
    
        /// <summary>
        /// Get information about wine Gets information about wine. Returning response body fields could be selected using _fields_ parameter. This method works without any authorization.
        /// </summary>
        /// <param name="wineId">Identificator of wine.</param>
        /// <param name="fields">Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value.</param>
        /// <returns>Wine</returns>
        public Wine GetWine (long? wineId, List<string> fields)
        {
            // verify the required parameter 'wineId' is set
            if (wineId == null) throw new ApiException(400, "Missing required parameter 'wineId' when calling GetWine");
    
            var path = "/wine/{wine_id}";
            path = path.Replace("{format}", "json");
            path = path.Replace("{" + "wine_id" + "}", ApiClient.ParameterToString(wineId));
    
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (fields != null) queryParams.Add("fields", ApiClient.ParameterToString(fields)); // query parameter
                                        
            // authentication setting, if any
            String[] authSettings = new String[] {  };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling GetWine: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling GetWine: " + response.ErrorMessage, response.ErrorMessage);
    
            return (Wine) ApiClient.Deserialize(response.Content, typeof(Wine), response.Headers);
        }
    
        /// <summary>
        /// List wines Searches wines owned by specified in _vineyard_id_ parameter winery by _name_, _country_, and/or _series_ names. This method works without any authorization.
        /// </summary>
        /// <param name="vineyardId">Identificator of winery.</param>
        /// <param name="name">Partial or full _name_ of the wine to be searched.</param>
        /// <param name="country">Numerical value of _country_ of wines to be displayed.</param>
        /// <param name="countryName">Partial or full _country_ name of the wine to be searched. If _country_ parameter is set this parameter will not take effect.</param>
        /// <param name="series">Numerical value of _series_ of wines to be displayed.</param>
        /// <param name="seriesName">Partial or full _series_ name of the wine to be searched. If _series_ parameter is set this parameter will not take effect.</param>
        /// <param name="year">_Year_ of vintages of wines to be returned. This field can be _exact value_ or an [_interval_](https://en.wikipedia.org/wiki/Interval_(mathematics)).</param>
        /// <param name="beverageType">Numerical value of primary _beverage type_ of wines to be displayed. Represents identificator of taxonomy term in _beverage_type_ taxonomy vocabulary without parents.  NOTE: See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description.</param>
        /// <param name="beverageTypeSecondary">Numerical value of secondary _beverage type_ of wines to be displayed. Represents identificator of taxonomy term in _beverage_type_ taxonomy vocabulary with parents.  NOTE: This field depends on _beverage_type_ field. See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description.</param>
        /// <param name="color">Numerical value of _color_ of wines to be displayed. Represents identificator of taxonomy term in _wine_color_ taxonomy vocabulary.  NOTE: Presence of this field in response depends on the _beverageType_ value. See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description.</param>
        /// <param name="grapeCategory">Value of _grape category_ field of wines to be displayed.  NOTE: Presence of this field in response depends on the _color_ value. See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description.</param>
        /// <param name="co2">Numerical value of _co2_ of wines to be displayed. Represents identificator of taxonomy term in _co2_ taxonomy vocabulary.  NOTE: Presence of this field in response depends on the _beverageType_ value. See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description.</param>
        /// <param name="method">Numerical value of _method_ of wines to be displayed. Represents identificator of taxonomy term in _method_ taxonomy vocabulary.  NOTE: Presence of this field in response depends on the _color_ value. See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description.</param>
        /// <param name="isExtraSweet">Value of _isExtraSweet_ field of wines to be displayed.  NOTE: Presence of this field in response depends on the _co2_ value. See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description.</param>
        /// <param name="isUnderFilmOfYeast">Value of _isUnderFilmOfYeast_ field of wines to be displayed.  NOTE: Presence of this field in response depends on the _co2_ value. See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description.</param>
        /// <param name="hasAwards">Defines if displayed wines must contain awards.</param>
        /// <param name="alcohol">Value of _alcohol_ amount of vintages of wines to be returned. This field can be _exact value_ or an [_interval_](https://en.wikipedia.org/wiki/Interval_(mathematics)).</param>
        /// <param name="sugar">Value of _sugar_ amount of vintages of wines to be returned. This field can be _exact value_ or an [_interval_](https://en.wikipedia.org/wiki/Interval_(mathematics)).</param>
        /// <param name="region">Numerical value (_tid_) of _region_ of wines to be displayed.</param>
        /// <param name="regionName">Full or partial name of _region_ of wines to be displayed. If _region_ parameter is set this parameter will not take effect.</param>
        /// <param name="isIgp">Value of _isIGP_ of wines to be displayed.</param>
        /// <param name="grapes">Separated by space numerical values (_tid_) of _grapes_ included in wines to be displayed.</param>
        /// <param name="fields">Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value.</param>
        /// <param name="offset">Specifies the number of objects to skip before server starts to return objects from the request query.</param>
        /// <param name="limit">Limits the objects returned in a response to a specified number of objects.</param>
        /// <param name="sort">Specifies a field on which to sort the response.</param>
        /// <param name="order">Specifies that the values in the specified field should be sorted in ascending or descending order. Takes effect only if _sort_ parameter defined.</param>
        /// <returns>WineList</returns>
        public WineList ListVineyardWines (long? vineyardId, string name, long? country, string countryName, long? series, string seriesName, string year, long? beverageType, long? beverageTypeSecondary, long? color, string grapeCategory, long? co2, long? method, string isExtraSweet, string isUnderFilmOfYeast, bool? hasAwards, string alcohol, string sugar, long? region, string regionName, bool? isIgp, List<long?> grapes, List<string> fields, long? offset, long? limit, string sort, string order)
        {
            // verify the required parameter 'vineyardId' is set
            if (vineyardId == null) throw new ApiException(400, "Missing required parameter 'vineyardId' when calling ListVineyardWines");
    
            var path = "/vineyard/{vineyard_id}/wine/list";
            path = path.Replace("{format}", "json");
            path = path.Replace("{" + "vineyard_id" + "}", ApiClient.ParameterToString(vineyardId));
    
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (name != null) queryParams.Add("name", ApiClient.ParameterToString(name)); // query parameter
 if (country != null) queryParams.Add("country", ApiClient.ParameterToString(country)); // query parameter
 if (countryName != null) queryParams.Add("country_name", ApiClient.ParameterToString(countryName)); // query parameter
 if (series != null) queryParams.Add("series", ApiClient.ParameterToString(series)); // query parameter
 if (seriesName != null) queryParams.Add("series_name", ApiClient.ParameterToString(seriesName)); // query parameter
 if (year != null) queryParams.Add("year", ApiClient.ParameterToString(year)); // query parameter
 if (beverageType != null) queryParams.Add("beverage_type", ApiClient.ParameterToString(beverageType)); // query parameter
 if (beverageTypeSecondary != null) queryParams.Add("beverage_type_secondary", ApiClient.ParameterToString(beverageTypeSecondary)); // query parameter
 if (color != null) queryParams.Add("color", ApiClient.ParameterToString(color)); // query parameter
 if (grapeCategory != null) queryParams.Add("grape_category", ApiClient.ParameterToString(grapeCategory)); // query parameter
 if (co2 != null) queryParams.Add("co2", ApiClient.ParameterToString(co2)); // query parameter
 if (method != null) queryParams.Add("method", ApiClient.ParameterToString(method)); // query parameter
 if (isExtraSweet != null) queryParams.Add("is_extra_sweet", ApiClient.ParameterToString(isExtraSweet)); // query parameter
 if (isUnderFilmOfYeast != null) queryParams.Add("is_under_film_of_yeast", ApiClient.ParameterToString(isUnderFilmOfYeast)); // query parameter
 if (hasAwards != null) queryParams.Add("has_awards", ApiClient.ParameterToString(hasAwards)); // query parameter
 if (alcohol != null) queryParams.Add("alcohol", ApiClient.ParameterToString(alcohol)); // query parameter
 if (sugar != null) queryParams.Add("sugar", ApiClient.ParameterToString(sugar)); // query parameter
 if (region != null) queryParams.Add("region", ApiClient.ParameterToString(region)); // query parameter
 if (regionName != null) queryParams.Add("region_name", ApiClient.ParameterToString(regionName)); // query parameter
 if (isIgp != null) queryParams.Add("is_igp", ApiClient.ParameterToString(isIgp)); // query parameter
 if (grapes != null) queryParams.Add("grapes", ApiClient.ParameterToString(grapes)); // query parameter
 if (fields != null) queryParams.Add("fields", ApiClient.ParameterToString(fields)); // query parameter
 if (offset != null) queryParams.Add("offset", ApiClient.ParameterToString(offset)); // query parameter
 if (limit != null) queryParams.Add("limit", ApiClient.ParameterToString(limit)); // query parameter
 if (sort != null) queryParams.Add("sort", ApiClient.ParameterToString(sort)); // query parameter
 if (order != null) queryParams.Add("order", ApiClient.ParameterToString(order)); // query parameter
                                        
            // authentication setting, if any
            String[] authSettings = new String[] {  };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling ListVineyardWines: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling ListVineyardWines: " + response.ErrorMessage, response.ErrorMessage);
    
            return (WineList) ApiClient.Deserialize(response.Content, typeof(WineList), response.Headers);
        }
    
        /// <summary>
        /// List wines Searches wines by _name_, _country_, and/or _series_ names. This method works without any authorization.
        /// </summary>
        /// <param name="name">Partial or full _name_ of the wine to be searched.</param>
        /// <param name="country">Numerical value of _country_ of wines to be displayed.</param>
        /// <param name="countryName">Partial or full _country_ name of the wine to be searched. If _country_ parameter is set this parameter will not take effect.</param>
        /// <param name="series">Numerical value of _series_ of wines to be displayed.</param>
        /// <param name="seriesName">Partial or full _series_ name of the wine to be searched. If _series_ parameter is set this parameter will not take effect.</param>
        /// <param name="year">_Year_ of vintages of wines to be returned. This field can be _exact value_ or an [_interval_](https://en.wikipedia.org/wiki/Interval_(mathematics)).</param>
        /// <param name="beverageType">Numerical value of primary _beverage type_ of wines to be displayed. Represents identificator of taxonomy term in _beverage_type_ taxonomy vocabulary without parents.  NOTE: See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description.</param>
        /// <param name="beverageTypeSecondary">Numerical value of secondary _beverage type_ of wines to be displayed. Represents identificator of taxonomy term in _beverage_type_ taxonomy vocabulary with parents.  NOTE: This field depends on _beverage_type_ field. See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description.</param>
        /// <param name="color">Numerical value of _color_ of wines to be displayed. Represents identificator of taxonomy term in _wine_color_ taxonomy vocabulary.  NOTE: Presence of this field in response depends on the _beverageType_ value. See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description.</param>
        /// <param name="grapeCategory">Value of _grape category_ field of wines to be displayed.  NOTE: Presence of this field in response depends on the _color_ value. See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description.</param>
        /// <param name="co2">Numerical value of _co2_ of wines to be displayed. Represents identificator of taxonomy term in _co2_ taxonomy vocabulary.  NOTE: Presence of this field in response depends on the _beverageType_ value. See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description.</param>
        /// <param name="method">Numerical value of _method_ of wines to be displayed. Represents identificator of taxonomy term in _method_ taxonomy vocabulary.  NOTE: Presence of this field in response depends on the _color_ value. See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description.</param>
        /// <param name="isExtraSweet">Value of _isExtraSweet_ field of wines to be displayed.  NOTE: Presence of this field in response depends on the _co2_ value. See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description.</param>
        /// <param name="isUnderFilmOfYeast">Value of _isUnderFilmOfYeast_ field of wines to be displayed.  NOTE: Presence of this field in response depends on the _co2_ value. See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description.</param>
        /// <param name="hasAwards">Defines if displayed wines must contain awards.</param>
        /// <param name="alcohol">Value of _alcohol_ amount of vintages of wines to be returned. This field can be _exact value_ or an [_interval_](https://en.wikipedia.org/wiki/Interval_(mathematics)).</param>
        /// <param name="sugar">Value of _sugar_ amount of vintages of wines to be returned. This field can be _exact value_ or an [_interval_](https://en.wikipedia.org/wiki/Interval_(mathematics)).</param>
        /// <param name="region">Numerical value (_tid_) of _region_ of wines to be displayed.</param>
        /// <param name="regionName">Full or partial name of _region_ of wines to be displayed. If _region_ parameter is set this parameter will not take effect.</param>
        /// <param name="isIgp">Value of _isIGP_ of wines to be displayed.</param>
        /// <param name="grapes">Separated by space numerical values (_tid_) of _grapes_ included in wines to be displayed.</param>
        /// <param name="fields">Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value.</param>
        /// <param name="offset">Specifies the number of objects to skip before server starts to return objects from the request query.</param>
        /// <param name="limit">Limits the objects returned in a response to a specified number of objects.</param>
        /// <param name="sort">Specifies a field on which to sort the response.</param>
        /// <param name="order">Specifies that the values in the specified field should be sorted in ascending or descending order. Takes effect only if _sort_ parameter defined.</param>
        /// <returns>WineList</returns>
        public WineList ListWines (string name, long? country, string countryName, long? series, string seriesName, string year, long? beverageType, long? beverageTypeSecondary, long? color, string grapeCategory, long? co2, long? method, string isExtraSweet, string isUnderFilmOfYeast, bool? hasAwards, string alcohol, string sugar, long? region, string regionName, bool? isIgp, List<long?> grapes, List<string> fields, long? offset, long? limit, string sort, string order)
        {
    
            var path = "/wine/list";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (name != null) queryParams.Add("name", ApiClient.ParameterToString(name)); // query parameter
 if (country != null) queryParams.Add("country", ApiClient.ParameterToString(country)); // query parameter
 if (countryName != null) queryParams.Add("country_name", ApiClient.ParameterToString(countryName)); // query parameter
 if (series != null) queryParams.Add("series", ApiClient.ParameterToString(series)); // query parameter
 if (seriesName != null) queryParams.Add("series_name", ApiClient.ParameterToString(seriesName)); // query parameter
 if (year != null) queryParams.Add("year", ApiClient.ParameterToString(year)); // query parameter
 if (beverageType != null) queryParams.Add("beverage_type", ApiClient.ParameterToString(beverageType)); // query parameter
 if (beverageTypeSecondary != null) queryParams.Add("beverage_type_secondary", ApiClient.ParameterToString(beverageTypeSecondary)); // query parameter
 if (color != null) queryParams.Add("color", ApiClient.ParameterToString(color)); // query parameter
 if (grapeCategory != null) queryParams.Add("grape_category", ApiClient.ParameterToString(grapeCategory)); // query parameter
 if (co2 != null) queryParams.Add("co2", ApiClient.ParameterToString(co2)); // query parameter
 if (method != null) queryParams.Add("method", ApiClient.ParameterToString(method)); // query parameter
 if (isExtraSweet != null) queryParams.Add("is_extra_sweet", ApiClient.ParameterToString(isExtraSweet)); // query parameter
 if (isUnderFilmOfYeast != null) queryParams.Add("is_under_film_of_yeast", ApiClient.ParameterToString(isUnderFilmOfYeast)); // query parameter
 if (hasAwards != null) queryParams.Add("has_awards", ApiClient.ParameterToString(hasAwards)); // query parameter
 if (alcohol != null) queryParams.Add("alcohol", ApiClient.ParameterToString(alcohol)); // query parameter
 if (sugar != null) queryParams.Add("sugar", ApiClient.ParameterToString(sugar)); // query parameter
 if (region != null) queryParams.Add("region", ApiClient.ParameterToString(region)); // query parameter
 if (regionName != null) queryParams.Add("region_name", ApiClient.ParameterToString(regionName)); // query parameter
 if (isIgp != null) queryParams.Add("is_igp", ApiClient.ParameterToString(isIgp)); // query parameter
 if (grapes != null) queryParams.Add("grapes", ApiClient.ParameterToString(grapes)); // query parameter
 if (fields != null) queryParams.Add("fields", ApiClient.ParameterToString(fields)); // query parameter
 if (offset != null) queryParams.Add("offset", ApiClient.ParameterToString(offset)); // query parameter
 if (limit != null) queryParams.Add("limit", ApiClient.ParameterToString(limit)); // query parameter
 if (sort != null) queryParams.Add("sort", ApiClient.ParameterToString(sort)); // query parameter
 if (order != null) queryParams.Add("order", ApiClient.ParameterToString(order)); // query parameter
                                        
            // authentication setting, if any
            String[] authSettings = new String[] {  };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling ListWines: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling ListWines: " + response.ErrorMessage, response.ErrorMessage);
    
            return (WineList) ApiClient.Deserialize(response.Content, typeof(WineList), response.Headers);
        }
    
        /// <summary>
        /// Update information about wine Updates information about beverage. In case of success, returns actual information about updated beverage.  - If beverage type is __wine__, request SHOULD contain _color_ and _co2_ values, otherwise it MUST contain _beverageTypeSecondary_ field.  - If __wine__&#x27;s _color_ is white, request MUST contain _grapeCategory_ value.  - If amount of co2 in __wine__ is less than 0.5 bar, request MUST contain _isExtraSweet_ and _isUnderFilmOfYeast_ fields, but if more than 2.5 bar - _method_ field.  Returning response body fields could be selected using _fields_ parameter.  WARNING: Be careful wrong parameter _wine_id_ can throw _insuficient_rights_ error.
        /// </summary>
        /// <param name="wineId">Identificator of wine.</param>
        /// <param name="body">Request body __SHOULD__ contain only fields with new values. _Fields_ parameter __SHOULD__ contain same fields as request body.</param>
        /// <param name="fields">Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value.</param>
        /// <returns>Wine</returns>
        public Wine UpdateWine (long? wineId, Wine body, List<string> fields)
        {
            // verify the required parameter 'wineId' is set
            if (wineId == null) throw new ApiException(400, "Missing required parameter 'wineId' when calling UpdateWine");
    
            var path = "/wine/{wine_id}";
            path = path.Replace("{format}", "json");
            path = path.Replace("{" + "wine_id" + "}", ApiClient.ParameterToString(wineId));
    
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (fields != null) queryParams.Add("fields", ApiClient.ParameterToString(fields)); // query parameter
                                    postBody = ApiClient.Serialize(body); // http body (model) parameter
    
            // authentication setting, if any
            String[] authSettings = new String[] { "common" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.PUT, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling UpdateWine: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling UpdateWine: " + response.ErrorMessage, response.ErrorMessage);
    
            return (Wine) ApiClient.Deserialize(response.Content, typeof(Wine), response.Headers);
        }
    
    }
}
