using System;
using System.Text;
using System.Collections;
using System.Collections.Generic;
using System.Runtime.Serialization;
using Newtonsoft.Json;

namespace IO.Swagger.Model {

  /// <summary>
  /// Information about winery.
  /// </summary>
  [DataContract]
  public class Vineyard {
    /// <summary>
    /// Vineyard identificator.
    /// </summary>
    /// <value>Vineyard identificator.</value>
    [DataMember(Name="id", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "id")]
    public long? Id { get; set; }

    /// <summary>
    /// Gets or Sets Name
    /// </summary>
    [DataMember(Name="name", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "name")]
    public string Name { get; set; }

    /// <summary>
    /// Country where winery is located. Represents identificator of taxonomy term in country taxonomy vocabulary.
    /// </summary>
    /// <value>Country where winery is located. Represents identificator of taxonomy term in country taxonomy vocabulary.</value>
    [DataMember(Name="country", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "country")]
    public long? Country { get; set; }

    /// <summary>
    /// Region where winery is located.
    /// </summary>
    /// <value>Region where winery is located.</value>
    [DataMember(Name="region", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "region")]
    public string Region { get; set; }

    /// <summary>
    /// Contact phone number of winery.
    /// </summary>
    /// <value>Contact phone number of winery.</value>
    [DataMember(Name="phone", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "phone")]
    public string Phone { get; set; }

    /// <summary>
    /// A long description of winery.
    /// </summary>
    /// <value>A long description of winery.</value>
    [DataMember(Name="description", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "description")]
    public string Description { get; set; }

    /// <summary>
    /// Gets or Sets Logo
    /// </summary>
    [DataMember(Name="logo", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "logo")]
    public File Logo { get; set; }

    /// <summary>
    /// Timestamp when winery was created.
    /// </summary>
    /// <value>Timestamp when winery was created.</value>
    [DataMember(Name="created", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "created")]
    public int? Created { get; set; }

    /// <summary>
    /// Timestamp when winery was last modified.
    /// </summary>
    /// <value>Timestamp when winery was last modified.</value>
    [DataMember(Name="updated", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "updated")]
    public int? Updated { get; set; }

    /// <summary>
    /// Gets or Sets Website
    /// </summary>
    [DataMember(Name="website", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "website")]
    public string Website { get; set; }

    /// <summary>
    /// Photos of winery. Supported maximum 6 photos.
    /// </summary>
    /// <value>Photos of winery. Supported maximum 6 photos.</value>
    [DataMember(Name="photos", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "photos")]
    public List<File> Photos { get; set; }


    /// <summary>
    /// Get the string presentation of the object
    /// </summary>
    /// <returns>String presentation of the object</returns>
    public override string ToString()  {
      var sb = new StringBuilder();
      sb.Append("class Vineyard {\n");
      sb.Append("  Id: ").Append(Id).Append("\n");
      sb.Append("  Name: ").Append(Name).Append("\n");
      sb.Append("  Country: ").Append(Country).Append("\n");
      sb.Append("  Region: ").Append(Region).Append("\n");
      sb.Append("  Phone: ").Append(Phone).Append("\n");
      sb.Append("  Description: ").Append(Description).Append("\n");
      sb.Append("  Logo: ").Append(Logo).Append("\n");
      sb.Append("  Created: ").Append(Created).Append("\n");
      sb.Append("  Updated: ").Append(Updated).Append("\n");
      sb.Append("  Website: ").Append(Website).Append("\n");
      sb.Append("  Photos: ").Append(Photos).Append("\n");
      sb.Append("}\n");
      return sb.ToString();
    }

    /// <summary>
    /// Get the JSON string presentation of the object
    /// </summary>
    /// <returns>JSON string presentation of the object</returns>
    public string ToJson() {
      return JsonConvert.SerializeObject(this, Formatting.Indented);
    }

}
}
