using System;
using System.Text;
using System.Collections;
using System.Collections.Generic;
using System.Runtime.Serialization;
using Newtonsoft.Json;

namespace IO.Swagger.Model {

  /// <summary>
  /// An extendable vocabulary which implements flat or hierarchy data structure.
  /// </summary>
  [DataContract]
  public class Vocabulary {
    /// <summary>
    /// Taxonomy vocabulary identificator (_vid_).
    /// </summary>
    /// <value>Taxonomy vocabulary identificator (_vid_).</value>
    [DataMember(Name="id", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "id")]
    public int? Id { get; set; }

    /// <summary>
    /// Displayable taxonomy vocabulary name.
    /// </summary>
    /// <value>Displayable taxonomy vocabulary name.</value>
    [DataMember(Name="name", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "name")]
    public string Name { get; set; }

    /// <summary>
    /// Unique untranslatable taxonomy vocabulary name. Сan be used as identificator.
    /// </summary>
    /// <value>Unique untranslatable taxonomy vocabulary name. Сan be used as identificator.</value>
    [DataMember(Name="machine_name", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "machine_name")]
    public string MachineName { get; set; }

    /// <summary>
    /// Short description of taxonomy vocabulary.
    /// </summary>
    /// <value>Short description of taxonomy vocabulary.</value>
    [DataMember(Name="description", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "description")]
    public string Description { get; set; }

    /// <summary>
    /// Indicates if taxonomy vocabulary has hierarchical structure. If _FALSE_, term's parent values are zero.
    /// </summary>
    /// <value>Indicates if taxonomy vocabulary has hierarchical structure. If _FALSE_, term's parent values are zero.</value>
    [DataMember(Name="hierarchy", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "hierarchy")]
    public bool? Hierarchy { get; set; }

    /// <summary>
    /// Taxonomy terms contained in vocabulary.
    /// </summary>
    /// <value>Taxonomy terms contained in vocabulary.</value>
    [DataMember(Name="terms", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "terms")]
    public List<Term> Terms { get; set; }


    /// <summary>
    /// Get the string presentation of the object
    /// </summary>
    /// <returns>String presentation of the object</returns>
    public override string ToString()  {
      var sb = new StringBuilder();
      sb.Append("class Vocabulary {\n");
      sb.Append("  Id: ").Append(Id).Append("\n");
      sb.Append("  Name: ").Append(Name).Append("\n");
      sb.Append("  MachineName: ").Append(MachineName).Append("\n");
      sb.Append("  Description: ").Append(Description).Append("\n");
      sb.Append("  Hierarchy: ").Append(Hierarchy).Append("\n");
      sb.Append("  Terms: ").Append(Terms).Append("\n");
      sb.Append("}\n");
      return sb.ToString();
    }

    /// <summary>
    /// Get the JSON string presentation of the object
    /// </summary>
    /// <returns>JSON string presentation of the object</returns>
    public string ToJson() {
      return JsonConvert.SerializeObject(this, Formatting.Indented);
    }

}
}
