using System;
using System.Text;
using System.Collections;
using System.Collections.Generic;
using System.Runtime.Serialization;
using Newtonsoft.Json;

namespace IO.Swagger.Model {

  /// <summary>
  /// Common information about wine.
  /// </summary>
  [DataContract]
  public class Wine {
    /// <summary>
    /// Wine identificator.
    /// </summary>
    /// <value>Wine identificator.</value>
    [DataMember(Name="id", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "id")]
    public long? Id { get; set; }

    /// <summary>
    /// Name of wine.
    /// </summary>
    /// <value>Name of wine.</value>
    [DataMember(Name="name", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "name")]
    public string Name { get; set; }

    /// <summary>
    /// Country where wine was produced. Represents identificator of taxonomy term in _country_ taxonomy vocabulary.
    /// </summary>
    /// <value>Country where wine was produced. Represents identificator of taxonomy term in _country_ taxonomy vocabulary.</value>
    [DataMember(Name="country", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "country")]
    public long? Country { get; set; }

    /// <summary>
    /// Gets or Sets Series
    /// </summary>
    [DataMember(Name="series", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "series")]
    public Seria Series { get; set; }

    /// <summary>
    /// Indicates if wine seria should be included in wine name.
    /// </summary>
    /// <value>Indicates if wine seria should be included in wine name.</value>
    [DataMember(Name="includeSeriesInName", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "includeSeriesInName")]
    public bool? IncludeSeriesInName { get; set; }

    /// <summary>
    /// Timestamp when wine was created.
    /// </summary>
    /// <value>Timestamp when wine was created.</value>
    [DataMember(Name="created", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "created")]
    public int? Created { get; set; }

    /// <summary>
    /// Timestamp when wine was last modified.
    /// </summary>
    /// <value>Timestamp when wine was last modified.</value>
    [DataMember(Name="updated", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "updated")]
    public int? Updated { get; set; }

    /// <summary>
    /// Owner of wine. Is displayed only for _/wine/list_ requests.
    /// </summary>
    /// <value>Owner of wine. Is displayed only for _/wine/list_ requests.</value>
    [DataMember(Name="vineyard", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "vineyard")]
    public long? Vineyard { get; set; }

    /// <summary>
    /// Type of beverage. Represents identificator of taxonomy term in _beverage_type_ taxonomy vocabulary.
    /// </summary>
    /// <value>Type of beverage. Represents identificator of taxonomy term in _beverage_type_ taxonomy vocabulary.</value>
    [DataMember(Name="beverageType", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "beverageType")]
    public long? BeverageType { get; set; }

    /// <summary>
    /// Secondary type of beverage. Represents identificator of taxonomy term in _beverage_type_ taxonomy vocabulary.  NOTE: This value depends on the _beverageType_ one. See _beverageType_ hierarchy.
    /// </summary>
    /// <value>Secondary type of beverage. Represents identificator of taxonomy term in _beverage_type_ taxonomy vocabulary.  NOTE: This value depends on the _beverageType_ one. See _beverageType_ hierarchy.</value>
    [DataMember(Name="beverageTypeSecondary", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "beverageTypeSecondary")]
    public long? BeverageTypeSecondary { get; set; }

    /// <summary>
    /// Color of wine. Represents identificator of taxonomy term in _wine_color_ taxonomy vocabulary.  NOTE: Presence of this field depends on the _beverageType_ value.
    /// </summary>
    /// <value>Color of wine. Represents identificator of taxonomy term in _wine_color_ taxonomy vocabulary.  NOTE: Presence of this field depends on the _beverageType_ value.</value>
    [DataMember(Name="color", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "color")]
    public long? Color { get; set; }

    /// <summary>
    /// Indicates if is aromatic wine or not.
    /// </summary>
    /// <value>Indicates if is aromatic wine or not.</value>
    [DataMember(Name="grapeCategory", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "grapeCategory")]
    public string GrapeCategory { get; set; }

    /// <summary>
    /// Amount of CO2 in wine. Represents identificator of taxonomy term in _co2_ taxonomy vocabulary.  NOTE: Presence of this field depends on the _beverageType_ value.
    /// </summary>
    /// <value>Amount of CO2 in wine. Represents identificator of taxonomy term in _co2_ taxonomy vocabulary.  NOTE: Presence of this field depends on the _beverageType_ value.</value>
    [DataMember(Name="co2", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "co2")]
    public long? Co2 { get; set; }

    /// <summary>
    /// Way of wine producing. Represents identificator of taxonomy term in _method_ taxonomy vocabulary.
    /// </summary>
    /// <value>Way of wine producing. Represents identificator of taxonomy term in _method_ taxonomy vocabulary.</value>
    [DataMember(Name="method", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "method")]
    public long? Method { get; set; }

    /// <summary>
    /// Indicates if wine is extra sweet.  NOTE: _yes_ means that wine is naturally sweet.
    /// </summary>
    /// <value>Indicates if wine is extra sweet.  NOTE: _yes_ means that wine is naturally sweet.</value>
    [DataMember(Name="isExtraSweet", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "isExtraSweet")]
    public string IsExtraSweet { get; set; }

    /// <summary>
    /// Indicates if wine is under a film of yeast.
    /// </summary>
    /// <value>Indicates if wine is under a film of yeast.</value>
    [DataMember(Name="isUnderFilmOfYeast", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "isUnderFilmOfYeast")]
    public string IsUnderFilmOfYeast { get; set; }


    /// <summary>
    /// Get the string presentation of the object
    /// </summary>
    /// <returns>String presentation of the object</returns>
    public override string ToString()  {
      var sb = new StringBuilder();
      sb.Append("class Wine {\n");
      sb.Append("  Id: ").Append(Id).Append("\n");
      sb.Append("  Name: ").Append(Name).Append("\n");
      sb.Append("  Country: ").Append(Country).Append("\n");
      sb.Append("  Series: ").Append(Series).Append("\n");
      sb.Append("  IncludeSeriesInName: ").Append(IncludeSeriesInName).Append("\n");
      sb.Append("  Created: ").Append(Created).Append("\n");
      sb.Append("  Updated: ").Append(Updated).Append("\n");
      sb.Append("  Vineyard: ").Append(Vineyard).Append("\n");
      sb.Append("  BeverageType: ").Append(BeverageType).Append("\n");
      sb.Append("  BeverageTypeSecondary: ").Append(BeverageTypeSecondary).Append("\n");
      sb.Append("  Color: ").Append(Color).Append("\n");
      sb.Append("  GrapeCategory: ").Append(GrapeCategory).Append("\n");
      sb.Append("  Co2: ").Append(Co2).Append("\n");
      sb.Append("  Method: ").Append(Method).Append("\n");
      sb.Append("  IsExtraSweet: ").Append(IsExtraSweet).Append("\n");
      sb.Append("  IsUnderFilmOfYeast: ").Append(IsUnderFilmOfYeast).Append("\n");
      sb.Append("}\n");
      return sb.ToString();
    }

    /// <summary>
    /// Get the JSON string presentation of the object
    /// </summary>
    /// <returns>JSON string presentation of the object</returns>
    public string ToJson() {
      return JsonConvert.SerializeObject(this, Formatting.Indented);
    }

}
}
