using System;
using System.Text;
using System.Collections;
using System.Collections.Generic;
using System.Runtime.Serialization;
using Newtonsoft.Json;

namespace IO.Swagger.Model {

  /// <summary>
  /// Object for creating wine together with the vintage.
  /// </summary>
  [DataContract]
  public class WineCreate {
    /// <summary>
    /// Wine identificator.
    /// </summary>
    /// <value>Wine identificator.</value>
    [DataMember(Name="wine_id", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "wine_id")]
    public long? WineId { get; set; }

    /// <summary>
    /// Name of wine.
    /// </summary>
    /// <value>Name of wine.</value>
    [DataMember(Name="name", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "name")]
    public string Name { get; set; }

    /// <summary>
    /// Country where wine was produced. Represents identificator of taxonomy term in _country_ taxonomy vocabulary.
    /// </summary>
    /// <value>Country where wine was produced. Represents identificator of taxonomy term in _country_ taxonomy vocabulary.</value>
    [DataMember(Name="country", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "country")]
    public long? Country { get; set; }

    /// <summary>
    /// Gets or Sets Series
    /// </summary>
    [DataMember(Name="series", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "series")]
    public Seria Series { get; set; }

    /// <summary>
    /// Indicates if wine seria should be included in wine name.
    /// </summary>
    /// <value>Indicates if wine seria should be included in wine name.</value>
    [DataMember(Name="includeSeriesInName", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "includeSeriesInName")]
    public bool? IncludeSeriesInName { get; set; }

    /// <summary>
    /// Type of beverage. Represents identificator of taxonomy term in _beverage_type_ taxonomy vocabulary.
    /// </summary>
    /// <value>Type of beverage. Represents identificator of taxonomy term in _beverage_type_ taxonomy vocabulary.</value>
    [DataMember(Name="beverageType", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "beverageType")]
    public long? BeverageType { get; set; }

    /// <summary>
    /// Secondary type of beverage. Represents identificator of taxonomy term in _beverage_type_ taxonomy vocabulary.  NOTE: This value depends on the _beverageType_ one. See _beverageType_ hierarchy.
    /// </summary>
    /// <value>Secondary type of beverage. Represents identificator of taxonomy term in _beverage_type_ taxonomy vocabulary.  NOTE: This value depends on the _beverageType_ one. See _beverageType_ hierarchy.</value>
    [DataMember(Name="beverageTypeSecondary", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "beverageTypeSecondary")]
    public long? BeverageTypeSecondary { get; set; }

    /// <summary>
    /// Color of wine. Represents identificator of taxonomy term in _color_ taxonomy vocabulary.  NOTE: Presence of this field depends on the _beverageType_ value.
    /// </summary>
    /// <value>Color of wine. Represents identificator of taxonomy term in _color_ taxonomy vocabulary.  NOTE: Presence of this field depends on the _beverageType_ value.</value>
    [DataMember(Name="color", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "color")]
    public long? Color { get; set; }

    /// <summary>
    /// Indicates if is aromatic wine or not.
    /// </summary>
    /// <value>Indicates if is aromatic wine or not.</value>
    [DataMember(Name="grapeCategory", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "grapeCategory")]
    public string GrapeCategory { get; set; }

    /// <summary>
    /// Amount of CO2 in wine. Represents identificator of taxonomy term in _co2_ taxonomy vocabulary.  NOTE: Presence of this field depends on the _beverageType_ value.
    /// </summary>
    /// <value>Amount of CO2 in wine. Represents identificator of taxonomy term in _co2_ taxonomy vocabulary.  NOTE: Presence of this field depends on the _beverageType_ value.</value>
    [DataMember(Name="co2", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "co2")]
    public long? Co2 { get; set; }

    /// <summary>
    /// Way of wine producing. Represents identificator of taxonomy term in _method_ taxonomy vocabulary.
    /// </summary>
    /// <value>Way of wine producing. Represents identificator of taxonomy term in _method_ taxonomy vocabulary.</value>
    [DataMember(Name="method", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "method")]
    public long? Method { get; set; }

    /// <summary>
    /// Indicates if wine is extra sweet.  NOTE: _yes_ means that wine is naturally sweet.
    /// </summary>
    /// <value>Indicates if wine is extra sweet.  NOTE: _yes_ means that wine is naturally sweet.</value>
    [DataMember(Name="isExtraSweet", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "isExtraSweet")]
    public string IsExtraSweet { get; set; }

    /// <summary>
    /// Indicates if wine is under a film of yeast.
    /// </summary>
    /// <value>Indicates if wine is under a film of yeast.</value>
    [DataMember(Name="isUnderFilmOfYeast", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "isUnderFilmOfYeast")]
    public string IsUnderFilmOfYeast { get; set; }

    /// <summary>
    /// Vintage identificator.
    /// </summary>
    /// <value>Vintage identificator.</value>
    [DataMember(Name="vintage_id", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "vintage_id")]
    public long? VintageId { get; set; }

    /// <summary>
    /// Gets or Sets Photo
    /// </summary>
    [DataMember(Name="photo", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "photo")]
    public File Photo { get; set; }

    /// <summary>
    /// Indicates if the _region_ is a protected geographical indication.
    /// </summary>
    /// <value>Indicates if the _region_ is a protected geographical indication.</value>
    [DataMember(Name="isIGP", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "isIGP")]
    public bool? IsIGP { get; set; }

    /// <summary>
    /// Stage of vintage production. Represents identificator of taxonomy term in _stage_of_wine_production_ taxonomy vocabulary.
    /// </summary>
    /// <value>Stage of vintage production. Represents identificator of taxonomy term in _stage_of_wine_production_ taxonomy vocabulary.</value>
    [DataMember(Name="stageOfProduction", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "stageOfProduction")]
    public long? StageOfProduction { get; set; }

    /// <summary>
    /// Production volume.
    /// </summary>
    /// <value>Production volume.</value>
    [DataMember(Name="productionVolume", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "productionVolume")]
    public float? ProductionVolume { get; set; }

    /// <summary>
    /// Production volume units. Represents identificator of taxonomy term in _production_volume_ taxonomy vocabulary.
    /// </summary>
    /// <value>Production volume units. Represents identificator of taxonomy term in _production_volume_ taxonomy vocabulary.</value>
    [DataMember(Name="productionUnits", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "productionUnits")]
    public long? ProductionUnits { get; set; }

    /// <summary>
    /// Amount of alcohol contained in vintage.
    /// </summary>
    /// <value>Amount of alcohol contained in vintage.</value>
    [DataMember(Name="alcohol", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "alcohol")]
    public float? Alcohol { get; set; }

    /// <summary>
    /// Amount of sugar contained in vintage.
    /// </summary>
    /// <value>Amount of sugar contained in vintage.</value>
    [DataMember(Name="sugar", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "sugar")]
    public float? Sugar { get; set; }

    /// <summary>
    /// A year when the vintage was produced.
    /// </summary>
    /// <value>A year when the vintage was produced.</value>
    [DataMember(Name="year", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "year")]
    public int? Year { get; set; }

    /// <summary>
    /// Timestamp when vintage was created.
    /// </summary>
    /// <value>Timestamp when vintage was created.</value>
    [DataMember(Name="created", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "created")]
    public int? Created { get; set; }

    /// <summary>
    /// Timestamp when vintage was last modified.
    /// </summary>
    /// <value>Timestamp when vintage was last modified.</value>
    [DataMember(Name="updated", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "updated")]
    public int? Updated { get; set; }

    /// <summary>
    /// Grape sorts and their percentage in wine.  NOTE: Total _percentage_ MUST be in range of 0 and 100.
    /// </summary>
    /// <value>Grape sorts and their percentage in wine.  NOTE: Total _percentage_ MUST be in range of 0 and 100.</value>
    [DataMember(Name="grapes", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "grapes")]
    public List<List<Object>> Grapes { get; set; }

    /// <summary>
    /// A region where the wine was produced.
    /// </summary>
    /// <value>A region where the wine was produced.</value>
    [DataMember(Name="region", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "region")]
    public long? Region { get; set; }

    /// <summary>
    /// Indicates if _region_ should be included in _wine_ _name_.
    /// </summary>
    /// <value>Indicates if _region_ should be included in _wine_ _name_.</value>
    [DataMember(Name="includeRegionInName", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "includeRegionInName")]
    public bool? IncludeRegionInName { get; set; }

    /// <summary>
    /// Gets or Sets CategorySimple
    /// </summary>
    [DataMember(Name="categorySimple", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "categorySimple")]
    public List<string> CategorySimple { get; set; }

    /// <summary>
    /// Gets or Sets CategoryProfessional
    /// </summary>
    [DataMember(Name="categoryProfessional", EmitDefaultValue=false)]
    [JsonProperty(PropertyName = "categoryProfessional")]
    public int? CategoryProfessional { get; set; }


    /// <summary>
    /// Get the string presentation of the object
    /// </summary>
    /// <returns>String presentation of the object</returns>
    public override string ToString()  {
      var sb = new StringBuilder();
      sb.Append("class WineCreate {\n");
      sb.Append("  WineId: ").Append(WineId).Append("\n");
      sb.Append("  Name: ").Append(Name).Append("\n");
      sb.Append("  Country: ").Append(Country).Append("\n");
      sb.Append("  Series: ").Append(Series).Append("\n");
      sb.Append("  IncludeSeriesInName: ").Append(IncludeSeriesInName).Append("\n");
      sb.Append("  BeverageType: ").Append(BeverageType).Append("\n");
      sb.Append("  BeverageTypeSecondary: ").Append(BeverageTypeSecondary).Append("\n");
      sb.Append("  Color: ").Append(Color).Append("\n");
      sb.Append("  GrapeCategory: ").Append(GrapeCategory).Append("\n");
      sb.Append("  Co2: ").Append(Co2).Append("\n");
      sb.Append("  Method: ").Append(Method).Append("\n");
      sb.Append("  IsExtraSweet: ").Append(IsExtraSweet).Append("\n");
      sb.Append("  IsUnderFilmOfYeast: ").Append(IsUnderFilmOfYeast).Append("\n");
      sb.Append("  VintageId: ").Append(VintageId).Append("\n");
      sb.Append("  Photo: ").Append(Photo).Append("\n");
      sb.Append("  IsIGP: ").Append(IsIGP).Append("\n");
      sb.Append("  StageOfProduction: ").Append(StageOfProduction).Append("\n");
      sb.Append("  ProductionVolume: ").Append(ProductionVolume).Append("\n");
      sb.Append("  ProductionUnits: ").Append(ProductionUnits).Append("\n");
      sb.Append("  Alcohol: ").Append(Alcohol).Append("\n");
      sb.Append("  Sugar: ").Append(Sugar).Append("\n");
      sb.Append("  Year: ").Append(Year).Append("\n");
      sb.Append("  Created: ").Append(Created).Append("\n");
      sb.Append("  Updated: ").Append(Updated).Append("\n");
      sb.Append("  Grapes: ").Append(Grapes).Append("\n");
      sb.Append("  Region: ").Append(Region).Append("\n");
      sb.Append("  IncludeRegionInName: ").Append(IncludeRegionInName).Append("\n");
      sb.Append("  CategorySimple: ").Append(CategorySimple).Append("\n");
      sb.Append("  CategoryProfessional: ").Append(CategoryProfessional).Append("\n");
      sb.Append("}\n");
      return sb.ToString();
    }

    /// <summary>
    /// Get the JSON string presentation of the object
    /// </summary>
    /// <returns>JSON string presentation of the object</returns>
    public string ToJson() {
      return JsonConvert.SerializeObject(this, Formatting.Indented);
    }

}
}
