# IO.Swagger.Api.AwardApi

All URIs are relative to *https://app.gustos.life/{language}/api/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**AddVintageAward**](AwardApi.md#addvintageaward) | **POST** /vintage/{vintage_id}/award/{award_id} | Add new award to vintage
[**GetAward**](AwardApi.md#getaward) | **GET** /award/{award_id} | Get information about award
[**ListCompetitionAwards**](AwardApi.md#listcompetitionawards) | **GET** /competition/{competition_id}/award/list | List awards
[**ListVintageAwards**](AwardApi.md#listvintageawards) | **GET** /vintage/{vintage_id}/award/list | List vintage awards
[**RemoveVintageAward**](AwardApi.md#removevintageaward) | **DELETE** /vintage/{vintage_id}/award/{award_id} | Remove award form vintage

<a name="addvintageaward"></a>
# **AddVintageAward**
> void AddVintageAward (Award body, long? vintageId, long? awardId)

Add new award to vintage

Adds specified in _award_id_ parameter award to specified in _vintage_id_ parameter vintage. In case of success, returns nothing.  NOTE: Award cannot be edited. To edit vintage award it SHOULD be deleted and added again.  WARNING: Be careful wrong parameter _vintage_id_ can throw _insuficient_rights_ error.

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class AddVintageAwardExample
    {
        public void main()
        {

            // Configure OAuth2 access token for authorization: common
            Configuration.Default.AccessToken = "YOUR_ACCESS_TOKEN";

            var apiInstance = new AwardApi();
            var body = new Award(); // Award | 
            var vintageId = 789;  // long? | Identificator of vintage.
            var awardId = 789;  // long? | Identificator of award.

            try
            {
                // Add new award to vintage
                apiInstance.AddVintageAward(body, vintageId, awardId);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling AwardApi.AddVintageAward: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**Award**](Award.md)|  | 
 **vintageId** | **long?**| Identificator of vintage. | 
 **awardId** | **long?**| Identificator of award. | 

### Return type

void (empty response body)

### Authorization

[common](../README.md#common)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="getaward"></a>
# **GetAward**
> Award GetAward (long? awardId, List<string> fields)

Get information about award

Gets information about award. Returning response body fields could be selected using _fields_ parameter. This method works without any authorization.

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class GetAwardExample
    {
        public void main()
        {

            var apiInstance = new AwardApi();
            var awardId = 789;  // long? | Identificator of award.
            var fields = new List<string>(); // List<string> | Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value. (optional) 

            try
            {
                // Get information about award
                Award result = apiInstance.GetAward(awardId, fields);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling AwardApi.GetAward: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **awardId** | **long?**| Identificator of award. | 
 **fields** | [**List<string>**](string.md)| Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value. | [optional] 

### Return type

[**Award**](Award.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="listcompetitionawards"></a>
# **ListCompetitionAwards**
> AwardList ListCompetitionAwards (long? competitionId, string name, List<string> fields, long? offset, long? limit, string sort, string order)

List awards

Searches awards by _name_. This method works without any authorization.

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class ListCompetitionAwardsExample
    {
        public void main()
        {

            var apiInstance = new AwardApi();
            var competitionId = 789;  // long? | Identificator of competition.
            var name = name_example;  // string | Partial or full _name_ of the award to be searched. (optional) 
            var fields = new List<string>(); // List<string> | Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value. (optional) 
            var offset = 789;  // long? | Specifies the number of objects to skip before server starts to return objects from the request query. (optional) 
            var limit = 789;  // long? | Limits the objects returned in a response to a specified number of objects. (optional) 
            var sort = sort_example;  // string | Specifies a field on which to sort the response. (optional) 
            var order = order_example;  // string | Specifies that the values in the specified field should be sorted in ascending or descending order. Takes effect only if _sort_ parameter defined. (optional) 

            try
            {
                // List awards
                AwardList result = apiInstance.ListCompetitionAwards(competitionId, name, fields, offset, limit, sort, order);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling AwardApi.ListCompetitionAwards: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **competitionId** | **long?**| Identificator of competition. | 
 **name** | **string**| Partial or full _name_ of the award to be searched. | [optional] 
 **fields** | [**List<string>**](string.md)| Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value. | [optional] 
 **offset** | **long?**| Specifies the number of objects to skip before server starts to return objects from the request query. | [optional] 
 **limit** | **long?**| Limits the objects returned in a response to a specified number of objects. | [optional] 
 **sort** | **string**| Specifies a field on which to sort the response. | [optional] 
 **order** | **string**| Specifies that the values in the specified field should be sorted in ascending or descending order. Takes effect only if _sort_ parameter defined. | [optional] 

### Return type

[**AwardList**](AwardList.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="listvintageawards"></a>
# **ListVintageAwards**
> AwardList ListVintageAwards (long? vintageId, string name, long? competition, string competitionName, string year, List<string> fields, long? offset, long? limit, string sort, string order)

List vintage awards

Searches awards by _name_, _competition_ and/or _year_ fields. This method works without any authorization.

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class ListVintageAwardsExample
    {
        public void main()
        {

            var apiInstance = new AwardApi();
            var vintageId = 789;  // long? | Identificator of vintage.
            var name = name_example;  // string | Partial or full _name_ of the award to be searched. (optional) 
            var competition = 789;  // long? | _Competition_ identificator where award was gained. (optional) 
            var competitionName = competitionName_example;  // string | Partial or full _name_ of the competition where award was gained. If _competition_ parameter is set this parameter will not take effect. (optional) 
            var year = year_example;  // string | _Year_ when award was gained. This field can be _exact value_ or an [_interval_](https://en.wikipedia.org/wiki/Interval_(mathematics)). (optional) 
            var fields = new List<string>(); // List<string> | Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value. (optional) 
            var offset = 789;  // long? | Specifies the number of objects to skip before server starts to return objects from the request query. (optional) 
            var limit = 789;  // long? | Limits the objects returned in a response to a specified number of objects. (optional) 
            var sort = sort_example;  // string | Specifies a field on which to sort the response. (optional) 
            var order = order_example;  // string | Specifies that the values in the specified field should be sorted in ascending or descending order. Takes effect only if _sort_ parameter defined. (optional) 

            try
            {
                // List vintage awards
                AwardList result = apiInstance.ListVintageAwards(vintageId, name, competition, competitionName, year, fields, offset, limit, sort, order);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling AwardApi.ListVintageAwards: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **vintageId** | **long?**| Identificator of vintage. | 
 **name** | **string**| Partial or full _name_ of the award to be searched. | [optional] 
 **competition** | **long?**| _Competition_ identificator where award was gained. | [optional] 
 **competitionName** | **string**| Partial or full _name_ of the competition where award was gained. If _competition_ parameter is set this parameter will not take effect. | [optional] 
 **year** | **string**| _Year_ when award was gained. This field can be _exact value_ or an [_interval_](https://en.wikipedia.org/wiki/Interval_(mathematics)). | [optional] 
 **fields** | [**List<string>**](string.md)| Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value. | [optional] 
 **offset** | **long?**| Specifies the number of objects to skip before server starts to return objects from the request query. | [optional] 
 **limit** | **long?**| Limits the objects returned in a response to a specified number of objects. | [optional] 
 **sort** | **string**| Specifies a field on which to sort the response. | [optional] 
 **order** | **string**| Specifies that the values in the specified field should be sorted in ascending or descending order. Takes effect only if _sort_ parameter defined. | [optional] 

### Return type

[**AwardList**](AwardList.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="removevintageaward"></a>
# **RemoveVintageAward**
> void RemoveVintageAward (Award body, long? vintageId, long? awardId)

Remove award form vintage

Removes specified in _award_id_ parameter award from specified in _vintage_id_ parameter vintage. In case of success, returns nothing.  NOTE: If body field _year_ is not specified, awards of any year will be removed.  WARNING: Be careful wrong parameter _vintage_id_ can throw _insuficient_rights_ error.

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class RemoveVintageAwardExample
    {
        public void main()
        {

            // Configure OAuth2 access token for authorization: common
            Configuration.Default.AccessToken = "YOUR_ACCESS_TOKEN";

            var apiInstance = new AwardApi();
            var body = new Award(); // Award | 
            var vintageId = 789;  // long? | Identificator of vintage.
            var awardId = 789;  // long? | Identificator of award.

            try
            {
                // Remove award form vintage
                apiInstance.RemoveVintageAward(body, vintageId, awardId);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling AwardApi.RemoveVintageAward: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**Award**](Award.md)|  | 
 **vintageId** | **long?**| Identificator of vintage. | 
 **awardId** | **long?**| Identificator of award. | 

### Return type

void (empty response body)

### Authorization

[common](../README.md#common)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

