# IO.Swagger.Api.VineyardApi

All URIs are relative to *https://app.gustos.life/{language}/api/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**CreateVineyard**](VineyardApi.md#createvineyard) | **POST** /vineyard | Create new winery
[**GetVineyard**](VineyardApi.md#getvineyard) | **GET** /vineyard/{vineyard_id} | Get information about winery
[**ListVineyards**](VineyardApi.md#listvineyards) | **GET** /vineyard/list | List wineries
[**UpdateVineyard**](VineyardApi.md#updatevineyard) | **PUT** /vineyard/{vineyard_id} | Update information about winery

<a name="createvineyard"></a>
# **CreateVineyard**
> void CreateVineyard (Body body)

Create new winery

Creates request for register new winery in the system.  Note: this method creates only __request__ to winery add. Winery will be created after checking by the moderator.

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class CreateVineyardExample
    {
        public void main()
        {

            // Configure OAuth2 access token for authorization: common
            Configuration.Default.AccessToken = "YOUR_ACCESS_TOKEN";

            var apiInstance = new VineyardApi();
            var body = new Body(); // Body | _Name_ and _email_ fields MUST be unique.

            try
            {
                // Create new winery
                apiInstance.CreateVineyard(body);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling VineyardApi.CreateVineyard: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**Body**](Body.md)| _Name_ and _email_ fields MUST be unique. | 

### Return type

void (empty response body)

### Authorization

[common](../README.md#common)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="getvineyard"></a>
# **GetVineyard**
> Vineyard GetVineyard (long? vineyardId, List<string> fields)

Get information about winery

Gets information about winery. Returning response body fields could be selected using _fields_ parameter. This method works without any authorization.

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class GetVineyardExample
    {
        public void main()
        {

            var apiInstance = new VineyardApi();
            var vineyardId = 789;  // long? | Identificator of winery.
            var fields = new List<string>(); // List<string> | Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value. (optional) 

            try
            {
                // Get information about winery
                Vineyard result = apiInstance.GetVineyard(vineyardId, fields);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling VineyardApi.GetVineyard: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **vineyardId** | **long?**| Identificator of winery. | 
 **fields** | [**List<string>**](string.md)| Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value. | [optional] 

### Return type

[**Vineyard**](Vineyard.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="listvineyards"></a>
# **ListVineyards**
> VineyardList ListVineyards (string name, string description, string region, long? country, string countryName, bool? hasAwards, List<string> fields, long? offset, long? limit, string sort, string order)

List wineries

Searches winery by _name_, _description_, _region_ and/or _country_ names. This method works without any authorization.

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class ListVineyardsExample
    {
        public void main()
        {

            var apiInstance = new VineyardApi();
            var name = name_example;  // string | Partial or full _name_ of the winery to be searched. (optional) 
            var description = description_example;  // string | Partial or full _description_ text of the winery to be searched. (optional) 
            var region = region_example;  // string | Partial or full _region_ name of the winery to be searched. (optional) 
            var country = 789;  // long? | Numerical value of _country_ of the wineries to be displayed. (optional) 
            var countryName = countryName_example;  // string | Partial or full _country_ name of the winery to be searched. (optional) 
            var hasAwards = true;  // bool? | Defines if wines of displayed vineyards must contain awards. (optional) 
            var fields = new List<string>(); // List<string> | Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value. (optional) 
            var offset = 789;  // long? | Specifies the number of objects to skip before server starts to return objects from the request query. (optional) 
            var limit = 789;  // long? | Limits the objects returned in a response to a specified number of objects. (optional) 
            var sort = sort_example;  // string | Specifies a field on which to sort the response. (optional) 
            var order = order_example;  // string | Specifies that the values in the specified field should be sorted in ascending or descending order. Takes effect only if _sort_ parameter defined. (optional) 

            try
            {
                // List wineries
                VineyardList result = apiInstance.ListVineyards(name, description, region, country, countryName, hasAwards, fields, offset, limit, sort, order);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling VineyardApi.ListVineyards: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **name** | **string**| Partial or full _name_ of the winery to be searched. | [optional] 
 **description** | **string**| Partial or full _description_ text of the winery to be searched. | [optional] 
 **region** | **string**| Partial or full _region_ name of the winery to be searched. | [optional] 
 **country** | **long?**| Numerical value of _country_ of the wineries to be displayed. | [optional] 
 **countryName** | **string**| Partial or full _country_ name of the winery to be searched. | [optional] 
 **hasAwards** | **bool?**| Defines if wines of displayed vineyards must contain awards. | [optional] 
 **fields** | [**List<string>**](string.md)| Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value. | [optional] 
 **offset** | **long?**| Specifies the number of objects to skip before server starts to return objects from the request query. | [optional] 
 **limit** | **long?**| Limits the objects returned in a response to a specified number of objects. | [optional] 
 **sort** | **string**| Specifies a field on which to sort the response. | [optional] 
 **order** | **string**| Specifies that the values in the specified field should be sorted in ascending or descending order. Takes effect only if _sort_ parameter defined. | [optional] 

### Return type

[**VineyardList**](VineyardList.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="updatevineyard"></a>
# **UpdateVineyard**
> Vineyard UpdateVineyard (long? vineyardId, Vineyard body, List<string> fields)

Update information about winery

Updates information about winery. In case of success, returns actual information about winery. Returning response body fields could be selected using _fields_ parameter.  WARNING: Be careful wrong parameter _vineyard_id_ can throw _insuficient_rights_ error.

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class UpdateVineyardExample
    {
        public void main()
        {

            // Configure OAuth2 access token for authorization: common
            Configuration.Default.AccessToken = "YOUR_ACCESS_TOKEN";

            var apiInstance = new VineyardApi();
            var vineyardId = 789;  // long? | Identificator of winery.
            var body = new Vineyard(); // Vineyard | Request body __SHOULD__ contain only fields with new values. _Fields_ parameter __SHOULD__ contain same fields as request body.

WARNING: Be careful wrong parameter can throw _insuficient_rights_ error. (optional) 
            var fields = new List<string>(); // List<string> | Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value. (optional) 

            try
            {
                // Update information about winery
                Vineyard result = apiInstance.UpdateVineyard(vineyardId, body, fields);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling VineyardApi.UpdateVineyard: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **vineyardId** | **long?**| Identificator of winery. | 
 **body** | [**Vineyard**](Vineyard.md)| Request body __SHOULD__ contain only fields with new values. _Fields_ parameter __SHOULD__ contain same fields as request body.

WARNING: Be careful wrong parameter can throw _insuficient_rights_ error. | [optional] 
 **fields** | [**List<string>**](string.md)| Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value. | [optional] 

### Return type

[**Vineyard**](Vineyard.md)

### Authorization

[common](../README.md#common)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

