# IO.Swagger.Api.VintageApi

All URIs are relative to *https://app.gustos.life/{language}/api/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**CreateVintage**](VintageApi.md#createvintage) | **POST** /wine/{wine_id}/vintage | Create new vintage
[**GetVintage**](VintageApi.md#getvintage) | **GET** /vintage/{vintage_id} | Get information about vintage
[**ListVintages**](VintageApi.md#listvintages) | **GET** /wine/{wine_id}/vintage/list | List vintages
[**UpdateVintage**](VintageApi.md#updatevintage) | **PUT** /vintage/{vintage_id} | Update information about vintage123

<a name="createvintage"></a>
# **CreateVintage**
> Vintage CreateVintage (Vintage body, long? wineId, List<string> fields)

Create new vintage

Adds vintage to specified in _wine_id_ parameter wine. In case of success, returns actual information about added vintage. Returning response body fields could be selected using _fields_ parameter.  WARNING: Be careful wrong parameter _wine_id_ can throw _insuficient_rights_ error.

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class CreateVintageExample
    {
        public void main()
        {

            // Configure OAuth2 access token for authorization: common
            Configuration.Default.AccessToken = "YOUR_ACCESS_TOKEN";

            var apiInstance = new VintageApi();
            var body = new Vintage(); // Vintage | 
            var wineId = 789;  // long? | Identificator of wine.
            var fields = new List<string>(); // List<string> | Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value. (optional) 

            try
            {
                // Create new vintage
                Vintage result = apiInstance.CreateVintage(body, wineId, fields);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling VintageApi.CreateVintage: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**Vintage**](Vintage.md)|  | 
 **wineId** | **long?**| Identificator of wine. | 
 **fields** | [**List<string>**](string.md)| Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value. | [optional] 

### Return type

[**Vintage**](Vintage.md)

### Authorization

[common](../README.md#common)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="getvintage"></a>
# **GetVintage**
> Vintage GetVintage (long? vintageId, List<string> fields)

Get information about vintage

Gets information about vintage. Returning response body fields could be selected using _fields_ parameter. This method works without any authorization.

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class GetVintageExample
    {
        public void main()
        {

            var apiInstance = new VintageApi();
            var vintageId = 789;  // long? | Identificator of vintage.
            var fields = new List<string>(); // List<string> | Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value. (optional) 

            try
            {
                // Get information about vintage
                Vintage result = apiInstance.GetVintage(vintageId, fields);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling VintageApi.GetVintage: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **vintageId** | **long?**| Identificator of vintage. | 
 **fields** | [**List<string>**](string.md)| Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value. | [optional] 

### Return type

[**Vintage**](Vintage.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="listvintages"></a>
# **ListVintages**
> VintageList ListVintages (long? wineId, string year, bool? hasAwards, string alcohol, string sugar, long? region, string regionName, bool? isIgp, List<long?> grapes, List<string> fields, long? offset, long? limit, string sort, string order)

List vintages

Gets list of all vintages of specified in _wine_id_ parameter wine. Returning objects could be filtered by _is_igp_, _stage_of_production_ and/or _region_ fields values. This method works without any authorization.

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class ListVintagesExample
    {
        public void main()
        {

            var apiInstance = new VintageApi();
            var wineId = 789;  // long? | Identificator of wine.
            var year = year_example;  // string | _Year_ of vintages to be returned. This field can be _exact value_ or an [_interval_](https://en.wikipedia.org/wiki/Interval_(mathematics)). (optional) 
            var hasAwards = true;  // bool? | Defines if displayed wines must contain awards. (optional) 
            var alcohol = alcohol_example;  // string | Value of _alcohol_ amount of vintages to be displayed. This field can be _exact value_ or an [_interval_](https://en.wikipedia.org/wiki/Interval_(mathematics)). (optional) 
            var sugar = sugar_example;  // string | Value of _sugar_ amount of vintages to be displayed. This field can be _exact value_ or an [_interval_](https://en.wikipedia.org/wiki/Interval_(mathematics)). (optional) 
            var region = 789;  // long? | Numerical value (_tid_) of _region_ of vintages to be displayed. (optional) 
            var regionName = regionName_example;  // string | Full or partial name of _region_ of vintages to be displayed. If _region_ parameter is set this parameter will not take effect. (optional) 
            var isIgp = true;  // bool? | Value of _isIGP_ of vintages to be displayed. (optional) 
            var grapes = new List<long?>(); // List<long?> | Separated by space numerical values (_tid_) of _grapes_ included in vintages to be displayed. (optional) 
            var fields = new List<string>(); // List<string> | Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value. (optional) 
            var offset = 789;  // long? | Specifies the number of objects to skip before server starts to return objects from the request query. (optional) 
            var limit = 789;  // long? | Limits the objects returned in a response to a specified number of objects. (optional) 
            var sort = sort_example;  // string | Specifies a field on which to sort the response. (optional) 
            var order = order_example;  // string | Specifies that the values in the specified field should be sorted in ascending or descending order. Takes effect only if _sort_ parameter defined. (optional) 

            try
            {
                // List vintages
                VintageList result = apiInstance.ListVintages(wineId, year, hasAwards, alcohol, sugar, region, regionName, isIgp, grapes, fields, offset, limit, sort, order);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling VintageApi.ListVintages: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **wineId** | **long?**| Identificator of wine. | 
 **year** | **string**| _Year_ of vintages to be returned. This field can be _exact value_ or an [_interval_](https://en.wikipedia.org/wiki/Interval_(mathematics)). | [optional] 
 **hasAwards** | **bool?**| Defines if displayed wines must contain awards. | [optional] 
 **alcohol** | **string**| Value of _alcohol_ amount of vintages to be displayed. This field can be _exact value_ or an [_interval_](https://en.wikipedia.org/wiki/Interval_(mathematics)). | [optional] 
 **sugar** | **string**| Value of _sugar_ amount of vintages to be displayed. This field can be _exact value_ or an [_interval_](https://en.wikipedia.org/wiki/Interval_(mathematics)). | [optional] 
 **region** | **long?**| Numerical value (_tid_) of _region_ of vintages to be displayed. | [optional] 
 **regionName** | **string**| Full or partial name of _region_ of vintages to be displayed. If _region_ parameter is set this parameter will not take effect. | [optional] 
 **isIgp** | **bool?**| Value of _isIGP_ of vintages to be displayed. | [optional] 
 **grapes** | [**List<long?>**](long?.md)| Separated by space numerical values (_tid_) of _grapes_ included in vintages to be displayed. | [optional] 
 **fields** | [**List<string>**](string.md)| Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value. | [optional] 
 **offset** | **long?**| Specifies the number of objects to skip before server starts to return objects from the request query. | [optional] 
 **limit** | **long?**| Limits the objects returned in a response to a specified number of objects. | [optional] 
 **sort** | **string**| Specifies a field on which to sort the response. | [optional] 
 **order** | **string**| Specifies that the values in the specified field should be sorted in ascending or descending order. Takes effect only if _sort_ parameter defined. | [optional] 

### Return type

[**VintageList**](VintageList.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="updatevintage"></a>
# **UpdateVintage**
> Vintage UpdateVintage (Vintage body, long? vintageId, List<string> fields)

Update information about vintage123

Updates information about vintage. In case of success, returns actual information about updated vintage. Returning response body fields could be selected using _fields_ parameter.  WARNING: Be careful wrong parameter _vineyard_id_ can throw _insuficient_rights_ error.

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class UpdateVintageExample
    {
        public void main()
        {

            // Configure OAuth2 access token for authorization: common
            Configuration.Default.AccessToken = "YOUR_ACCESS_TOKEN";

            var apiInstance = new VintageApi();
            var body = new Vintage(); // Vintage | Request body __SHOULD__ contain only fields with new values. _Fields_ parameter __SHOULD__ contain same fields as request body.
            var vintageId = 789;  // long? | Identificator of vintage.
            var fields = new List<string>(); // List<string> | Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value. (optional) 

            try
            {
                // Update information about vintage123
                Vintage result = apiInstance.UpdateVintage(body, vintageId, fields);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling VintageApi.UpdateVintage: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**Vintage**](Vintage.md)| Request body __SHOULD__ contain only fields with new values. _Fields_ parameter __SHOULD__ contain same fields as request body. | 
 **vintageId** | **long?**| Identificator of vintage. | 
 **fields** | [**List<string>**](string.md)| Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value. | [optional] 

### Return type

[**Vintage**](Vintage.md)

### Authorization

[common](../README.md#common)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

