# IO.Swagger.Api.WineApi

All URIs are relative to *https://app.gustos.life/{language}/api/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**CreateWine**](WineApi.md#createwine) | **POST** /vineyard/{vineyard_id}/wine | Create new wine
[**GetWine**](WineApi.md#getwine) | **GET** /wine/{wine_id} | Get information about wine
[**ListVineyardWines**](WineApi.md#listvineyardwines) | **GET** /vineyard/{vineyard_id}/wine/list | List wines
[**ListWines**](WineApi.md#listwines) | **GET** /wine/list | List wines
[**UpdateWine**](WineApi.md#updatewine) | **PUT** /wine/{wine_id} | Update information about wine

<a name="createwine"></a>
# **CreateWine**
> Wine CreateWine (WineCreate body, long? vineyardId, List<string> fields)

Create new wine

Creates wine and its vintage owned by specified in _vineyard_id_ parameter winery. In case of success, returns actual information about created wine.  - If beverage type is __wine__, request SHOULD contain _color_ and _co2_ values, otherwise it SHOULD contain _beverageTypeSecondary_ field.  - If __wine__'s _color_ is white, request SHOULD contain _grapeCategory_ value.  - If amount of co2 in __wine__ is less than 0.5 bar, request SHOULD contain _isExtraSweet_ and _isUnderFilmOfYeast_ fields, but if more than 2.5 bar - _method_ field.  Returning response body fields could be selected using _fields_ parameter.  WARNING: Be careful wrong parameter _vineyard_id_ can throw _insuficient_rights_ error.

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class CreateWineExample
    {
        public void main()
        {

            // Configure OAuth2 access token for authorization: common
            Configuration.Default.AccessToken = "YOUR_ACCESS_TOKEN";

            var apiInstance = new WineApi();
            var body = new WineCreate(); // WineCreate | 
            var vineyardId = 789;  // long? | Identificator of winery.
            var fields = new List<string>(); // List<string> | Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value. (optional) 

            try
            {
                // Create new wine
                Wine result = apiInstance.CreateWine(body, vineyardId, fields);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling WineApi.CreateWine: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**WineCreate**](WineCreate.md)|  | 
 **vineyardId** | **long?**| Identificator of winery. | 
 **fields** | [**List<string>**](string.md)| Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value. | [optional] 

### Return type

[**Wine**](Wine.md)

### Authorization

[common](../README.md#common)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="getwine"></a>
# **GetWine**
> Wine GetWine (long? wineId, List<string> fields)

Get information about wine

Gets information about wine. Returning response body fields could be selected using _fields_ parameter. This method works without any authorization.

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class GetWineExample
    {
        public void main()
        {

            var apiInstance = new WineApi();
            var wineId = 789;  // long? | Identificator of wine.
            var fields = new List<string>(); // List<string> | Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value. (optional) 

            try
            {
                // Get information about wine
                Wine result = apiInstance.GetWine(wineId, fields);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling WineApi.GetWine: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **wineId** | **long?**| Identificator of wine. | 
 **fields** | [**List<string>**](string.md)| Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value. | [optional] 

### Return type

[**Wine**](Wine.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="listvineyardwines"></a>
# **ListVineyardWines**
> WineList ListVineyardWines (long? vineyardId, string name, long? country, string countryName, long? series, string seriesName, string year, long? beverageType, long? beverageTypeSecondary, long? color, string grapeCategory, long? co2, long? method, string isExtraSweet, string isUnderFilmOfYeast, bool? hasAwards, string alcohol, string sugar, long? region, string regionName, bool? isIgp, List<long?> grapes, List<string> fields, long? offset, long? limit, string sort, string order)

List wines

Searches wines owned by specified in _vineyard_id_ parameter winery by _name_, _country_, and/or _series_ names. This method works without any authorization.

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class ListVineyardWinesExample
    {
        public void main()
        {

            var apiInstance = new WineApi();
            var vineyardId = 789;  // long? | Identificator of winery.
            var name = name_example;  // string | Partial or full _name_ of the wine to be searched. (optional) 
            var country = 789;  // long? | Numerical value of _country_ of wines to be displayed. (optional) 
            var countryName = countryName_example;  // string | Partial or full _country_ name of the wine to be searched. If _country_ parameter is set this parameter will not take effect. (optional) 
            var series = 789;  // long? | Numerical value of _series_ of wines to be displayed. (optional) 
            var seriesName = seriesName_example;  // string | Partial or full _series_ name of the wine to be searched. If _series_ parameter is set this parameter will not take effect. (optional) 
            var year = year_example;  // string | _Year_ of vintages of wines to be returned. This field can be _exact value_ or an [_interval_](https://en.wikipedia.org/wiki/Interval_(mathematics)). (optional) 
            var beverageType = 789;  // long? | Numerical value of primary _beverage type_ of wines to be displayed. Represents identificator of taxonomy term in _beverage_type_ taxonomy vocabulary without parents.  NOTE: See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description. (optional) 
            var beverageTypeSecondary = 789;  // long? | Numerical value of secondary _beverage type_ of wines to be displayed. Represents identificator of taxonomy term in _beverage_type_ taxonomy vocabulary with parents.  NOTE: This field depends on _beverage_type_ field. See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description. (optional) 
            var color = 789;  // long? | Numerical value of _color_ of wines to be displayed. Represents identificator of taxonomy term in _wine_color_ taxonomy vocabulary.  NOTE: Presence of this field in response depends on the _beverageType_ value. See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description. (optional) 
            var grapeCategory = grapeCategory_example;  // string | Value of _grape category_ field of wines to be displayed.  NOTE: Presence of this field in response depends on the _color_ value. See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description. (optional) 
            var co2 = 789;  // long? | Numerical value of _co2_ of wines to be displayed. Represents identificator of taxonomy term in _co2_ taxonomy vocabulary.  NOTE: Presence of this field in response depends on the _beverageType_ value. See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description. (optional) 
            var method = 789;  // long? | Numerical value of _method_ of wines to be displayed. Represents identificator of taxonomy term in _method_ taxonomy vocabulary.  NOTE: Presence of this field in response depends on the _color_ value. See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description. (optional) 
            var isExtraSweet = isExtraSweet_example;  // string | Value of _isExtraSweet_ field of wines to be displayed.  NOTE: Presence of this field in response depends on the _co2_ value. See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description. (optional) 
            var isUnderFilmOfYeast = isUnderFilmOfYeast_example;  // string | Value of _isUnderFilmOfYeast_ field of wines to be displayed.  NOTE: Presence of this field in response depends on the _co2_ value. See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description. (optional) 
            var hasAwards = true;  // bool? | Defines if displayed wines must contain awards. (optional) 
            var alcohol = alcohol_example;  // string | Value of _alcohol_ amount of vintages of wines to be returned. This field can be _exact value_ or an [_interval_](https://en.wikipedia.org/wiki/Interval_(mathematics)). (optional) 
            var sugar = sugar_example;  // string | Value of _sugar_ amount of vintages of wines to be returned. This field can be _exact value_ or an [_interval_](https://en.wikipedia.org/wiki/Interval_(mathematics)). (optional) 
            var region = 789;  // long? | Numerical value (_tid_) of _region_ of wines to be displayed. (optional) 
            var regionName = regionName_example;  // string | Full or partial name of _region_ of wines to be displayed. If _region_ parameter is set this parameter will not take effect. (optional) 
            var isIgp = true;  // bool? | Value of _isIGP_ of wines to be displayed. (optional) 
            var grapes = new List<long?>(); // List<long?> | Separated by space numerical values (_tid_) of _grapes_ included in wines to be displayed. (optional) 
            var fields = new List<string>(); // List<string> | Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value. (optional) 
            var offset = 789;  // long? | Specifies the number of objects to skip before server starts to return objects from the request query. (optional) 
            var limit = 789;  // long? | Limits the objects returned in a response to a specified number of objects. (optional) 
            var sort = sort_example;  // string | Specifies a field on which to sort the response. (optional) 
            var order = order_example;  // string | Specifies that the values in the specified field should be sorted in ascending or descending order. Takes effect only if _sort_ parameter defined. (optional) 

            try
            {
                // List wines
                WineList result = apiInstance.ListVineyardWines(vineyardId, name, country, countryName, series, seriesName, year, beverageType, beverageTypeSecondary, color, grapeCategory, co2, method, isExtraSweet, isUnderFilmOfYeast, hasAwards, alcohol, sugar, region, regionName, isIgp, grapes, fields, offset, limit, sort, order);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling WineApi.ListVineyardWines: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **vineyardId** | **long?**| Identificator of winery. | 
 **name** | **string**| Partial or full _name_ of the wine to be searched. | [optional] 
 **country** | **long?**| Numerical value of _country_ of wines to be displayed. | [optional] 
 **countryName** | **string**| Partial or full _country_ name of the wine to be searched. If _country_ parameter is set this parameter will not take effect. | [optional] 
 **series** | **long?**| Numerical value of _series_ of wines to be displayed. | [optional] 
 **seriesName** | **string**| Partial or full _series_ name of the wine to be searched. If _series_ parameter is set this parameter will not take effect. | [optional] 
 **year** | **string**| _Year_ of vintages of wines to be returned. This field can be _exact value_ or an [_interval_](https://en.wikipedia.org/wiki/Interval_(mathematics)). | [optional] 
 **beverageType** | **long?**| Numerical value of primary _beverage type_ of wines to be displayed. Represents identificator of taxonomy term in _beverage_type_ taxonomy vocabulary without parents.  NOTE: See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description. | [optional] 
 **beverageTypeSecondary** | **long?**| Numerical value of secondary _beverage type_ of wines to be displayed. Represents identificator of taxonomy term in _beverage_type_ taxonomy vocabulary with parents.  NOTE: This field depends on _beverage_type_ field. See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description. | [optional] 
 **color** | **long?**| Numerical value of _color_ of wines to be displayed. Represents identificator of taxonomy term in _wine_color_ taxonomy vocabulary.  NOTE: Presence of this field in response depends on the _beverageType_ value. See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description. | [optional] 
 **grapeCategory** | **string**| Value of _grape category_ field of wines to be displayed.  NOTE: Presence of this field in response depends on the _color_ value. See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description. | [optional] 
 **co2** | **long?**| Numerical value of _co2_ of wines to be displayed. Represents identificator of taxonomy term in _co2_ taxonomy vocabulary.  NOTE: Presence of this field in response depends on the _beverageType_ value. See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description. | [optional] 
 **method** | **long?**| Numerical value of _method_ of wines to be displayed. Represents identificator of taxonomy term in _method_ taxonomy vocabulary.  NOTE: Presence of this field in response depends on the _color_ value. See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description. | [optional] 
 **isExtraSweet** | **string**| Value of _isExtraSweet_ field of wines to be displayed.  NOTE: Presence of this field in response depends on the _co2_ value. See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description. | [optional] 
 **isUnderFilmOfYeast** | **string**| Value of _isUnderFilmOfYeast_ field of wines to be displayed.  NOTE: Presence of this field in response depends on the _co2_ value. See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description. | [optional] 
 **hasAwards** | **bool?**| Defines if displayed wines must contain awards. | [optional] 
 **alcohol** | **string**| Value of _alcohol_ amount of vintages of wines to be returned. This field can be _exact value_ or an [_interval_](https://en.wikipedia.org/wiki/Interval_(mathematics)). | [optional] 
 **sugar** | **string**| Value of _sugar_ amount of vintages of wines to be returned. This field can be _exact value_ or an [_interval_](https://en.wikipedia.org/wiki/Interval_(mathematics)). | [optional] 
 **region** | **long?**| Numerical value (_tid_) of _region_ of wines to be displayed. | [optional] 
 **regionName** | **string**| Full or partial name of _region_ of wines to be displayed. If _region_ parameter is set this parameter will not take effect. | [optional] 
 **isIgp** | **bool?**| Value of _isIGP_ of wines to be displayed. | [optional] 
 **grapes** | [**List<long?>**](long?.md)| Separated by space numerical values (_tid_) of _grapes_ included in wines to be displayed. | [optional] 
 **fields** | [**List<string>**](string.md)| Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value. | [optional] 
 **offset** | **long?**| Specifies the number of objects to skip before server starts to return objects from the request query. | [optional] 
 **limit** | **long?**| Limits the objects returned in a response to a specified number of objects. | [optional] 
 **sort** | **string**| Specifies a field on which to sort the response. | [optional] 
 **order** | **string**| Specifies that the values in the specified field should be sorted in ascending or descending order. Takes effect only if _sort_ parameter defined. | [optional] 

### Return type

[**WineList**](WineList.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="listwines"></a>
# **ListWines**
> WineList ListWines (string name, long? country, string countryName, long? series, string seriesName, string year, long? beverageType, long? beverageTypeSecondary, long? color, string grapeCategory, long? co2, long? method, string isExtraSweet, string isUnderFilmOfYeast, bool? hasAwards, string alcohol, string sugar, long? region, string regionName, bool? isIgp, List<long?> grapes, List<string> fields, long? offset, long? limit, string sort, string order)

List wines

Searches wines by _name_, _country_, and/or _series_ names. This method works without any authorization.

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class ListWinesExample
    {
        public void main()
        {

            var apiInstance = new WineApi();
            var name = name_example;  // string | Partial or full _name_ of the wine to be searched. (optional) 
            var country = 789;  // long? | Numerical value of _country_ of wines to be displayed. (optional) 
            var countryName = countryName_example;  // string | Partial or full _country_ name of the wine to be searched. If _country_ parameter is set this parameter will not take effect. (optional) 
            var series = 789;  // long? | Numerical value of _series_ of wines to be displayed. (optional) 
            var seriesName = seriesName_example;  // string | Partial or full _series_ name of the wine to be searched. If _series_ parameter is set this parameter will not take effect. (optional) 
            var year = year_example;  // string | _Year_ of vintages of wines to be returned. This field can be _exact value_ or an [_interval_](https://en.wikipedia.org/wiki/Interval_(mathematics)). (optional) 
            var beverageType = 789;  // long? | Numerical value of primary _beverage type_ of wines to be displayed. Represents identificator of taxonomy term in _beverage_type_ taxonomy vocabulary without parents.  NOTE: See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description. (optional) 
            var beverageTypeSecondary = 789;  // long? | Numerical value of secondary _beverage type_ of wines to be displayed. Represents identificator of taxonomy term in _beverage_type_ taxonomy vocabulary with parents.  NOTE: This field depends on _beverage_type_ field. See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description. (optional) 
            var color = 789;  // long? | Numerical value of _color_ of wines to be displayed. Represents identificator of taxonomy term in _wine_color_ taxonomy vocabulary.  NOTE: Presence of this field in response depends on the _beverageType_ value. See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description. (optional) 
            var grapeCategory = grapeCategory_example;  // string | Value of _grape category_ field of wines to be displayed.  NOTE: Presence of this field in response depends on the _color_ value. See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description. (optional) 
            var co2 = 789;  // long? | Numerical value of _co2_ of wines to be displayed. Represents identificator of taxonomy term in _co2_ taxonomy vocabulary.  NOTE: Presence of this field in response depends on the _beverageType_ value. See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description. (optional) 
            var method = 789;  // long? | Numerical value of _method_ of wines to be displayed. Represents identificator of taxonomy term in _method_ taxonomy vocabulary.  NOTE: Presence of this field in response depends on the _color_ value. See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description. (optional) 
            var isExtraSweet = isExtraSweet_example;  // string | Value of _isExtraSweet_ field of wines to be displayed.  NOTE: Presence of this field in response depends on the _co2_ value. See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description. (optional) 
            var isUnderFilmOfYeast = isUnderFilmOfYeast_example;  // string | Value of _isUnderFilmOfYeast_ field of wines to be displayed.  NOTE: Presence of this field in response depends on the _co2_ value. See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description. (optional) 
            var hasAwards = true;  // bool? | Defines if displayed wines must contain awards. (optional) 
            var alcohol = alcohol_example;  // string | Value of _alcohol_ amount of vintages of wines to be returned. This field can be _exact value_ or an [_interval_](https://en.wikipedia.org/wiki/Interval_(mathematics)). (optional) 
            var sugar = sugar_example;  // string | Value of _sugar_ amount of vintages of wines to be returned. This field can be _exact value_ or an [_interval_](https://en.wikipedia.org/wiki/Interval_(mathematics)). (optional) 
            var region = 789;  // long? | Numerical value (_tid_) of _region_ of wines to be displayed. (optional) 
            var regionName = regionName_example;  // string | Full or partial name of _region_ of wines to be displayed. If _region_ parameter is set this parameter will not take effect. (optional) 
            var isIgp = true;  // bool? | Value of _isIGP_ of wines to be displayed. (optional) 
            var grapes = new List<long?>(); // List<long?> | Separated by space numerical values (_tid_) of _grapes_ included in wines to be displayed. (optional) 
            var fields = new List<string>(); // List<string> | Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value. (optional) 
            var offset = 789;  // long? | Specifies the number of objects to skip before server starts to return objects from the request query. (optional) 
            var limit = 789;  // long? | Limits the objects returned in a response to a specified number of objects. (optional) 
            var sort = sort_example;  // string | Specifies a field on which to sort the response. (optional) 
            var order = order_example;  // string | Specifies that the values in the specified field should be sorted in ascending or descending order. Takes effect only if _sort_ parameter defined. (optional) 

            try
            {
                // List wines
                WineList result = apiInstance.ListWines(name, country, countryName, series, seriesName, year, beverageType, beverageTypeSecondary, color, grapeCategory, co2, method, isExtraSweet, isUnderFilmOfYeast, hasAwards, alcohol, sugar, region, regionName, isIgp, grapes, fields, offset, limit, sort, order);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling WineApi.ListWines: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **name** | **string**| Partial or full _name_ of the wine to be searched. | [optional] 
 **country** | **long?**| Numerical value of _country_ of wines to be displayed. | [optional] 
 **countryName** | **string**| Partial or full _country_ name of the wine to be searched. If _country_ parameter is set this parameter will not take effect. | [optional] 
 **series** | **long?**| Numerical value of _series_ of wines to be displayed. | [optional] 
 **seriesName** | **string**| Partial or full _series_ name of the wine to be searched. If _series_ parameter is set this parameter will not take effect. | [optional] 
 **year** | **string**| _Year_ of vintages of wines to be returned. This field can be _exact value_ or an [_interval_](https://en.wikipedia.org/wiki/Interval_(mathematics)). | [optional] 
 **beverageType** | **long?**| Numerical value of primary _beverage type_ of wines to be displayed. Represents identificator of taxonomy term in _beverage_type_ taxonomy vocabulary without parents.  NOTE: See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description. | [optional] 
 **beverageTypeSecondary** | **long?**| Numerical value of secondary _beverage type_ of wines to be displayed. Represents identificator of taxonomy term in _beverage_type_ taxonomy vocabulary with parents.  NOTE: This field depends on _beverage_type_ field. See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description. | [optional] 
 **color** | **long?**| Numerical value of _color_ of wines to be displayed. Represents identificator of taxonomy term in _wine_color_ taxonomy vocabulary.  NOTE: Presence of this field in response depends on the _beverageType_ value. See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description. | [optional] 
 **grapeCategory** | **string**| Value of _grape category_ field of wines to be displayed.  NOTE: Presence of this field in response depends on the _color_ value. See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description. | [optional] 
 **co2** | **long?**| Numerical value of _co2_ of wines to be displayed. Represents identificator of taxonomy term in _co2_ taxonomy vocabulary.  NOTE: Presence of this field in response depends on the _beverageType_ value. See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description. | [optional] 
 **method** | **long?**| Numerical value of _method_ of wines to be displayed. Represents identificator of taxonomy term in _method_ taxonomy vocabulary.  NOTE: Presence of this field in response depends on the _color_ value. See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description. | [optional] 
 **isExtraSweet** | **string**| Value of _isExtraSweet_ field of wines to be displayed.  NOTE: Presence of this field in response depends on the _co2_ value. See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description. | [optional] 
 **isUnderFilmOfYeast** | **string**| Value of _isUnderFilmOfYeast_ field of wines to be displayed.  NOTE: Presence of this field in response depends on the _co2_ value. See field dependence in [PUT /wine/{wine}](#/wine/updateWine) description. | [optional] 
 **hasAwards** | **bool?**| Defines if displayed wines must contain awards. | [optional] 
 **alcohol** | **string**| Value of _alcohol_ amount of vintages of wines to be returned. This field can be _exact value_ or an [_interval_](https://en.wikipedia.org/wiki/Interval_(mathematics)). | [optional] 
 **sugar** | **string**| Value of _sugar_ amount of vintages of wines to be returned. This field can be _exact value_ or an [_interval_](https://en.wikipedia.org/wiki/Interval_(mathematics)). | [optional] 
 **region** | **long?**| Numerical value (_tid_) of _region_ of wines to be displayed. | [optional] 
 **regionName** | **string**| Full or partial name of _region_ of wines to be displayed. If _region_ parameter is set this parameter will not take effect. | [optional] 
 **isIgp** | **bool?**| Value of _isIGP_ of wines to be displayed. | [optional] 
 **grapes** | [**List<long?>**](long?.md)| Separated by space numerical values (_tid_) of _grapes_ included in wines to be displayed. | [optional] 
 **fields** | [**List<string>**](string.md)| Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value. | [optional] 
 **offset** | **long?**| Specifies the number of objects to skip before server starts to return objects from the request query. | [optional] 
 **limit** | **long?**| Limits the objects returned in a response to a specified number of objects. | [optional] 
 **sort** | **string**| Specifies a field on which to sort the response. | [optional] 
 **order** | **string**| Specifies that the values in the specified field should be sorted in ascending or descending order. Takes effect only if _sort_ parameter defined. | [optional] 

### Return type

[**WineList**](WineList.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="updatewine"></a>
# **UpdateWine**
> Wine UpdateWine (long? wineId, Wine body, List<string> fields)

Update information about wine

Updates information about beverage. In case of success, returns actual information about updated beverage.  - If beverage type is __wine__, request SHOULD contain _color_ and _co2_ values, otherwise it MUST contain _beverageTypeSecondary_ field.  - If __wine__'s _color_ is white, request MUST contain _grapeCategory_ value.  - If amount of co2 in __wine__ is less than 0.5 bar, request MUST contain _isExtraSweet_ and _isUnderFilmOfYeast_ fields, but if more than 2.5 bar - _method_ field.  Returning response body fields could be selected using _fields_ parameter.  WARNING: Be careful wrong parameter _wine_id_ can throw _insuficient_rights_ error.

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class UpdateWineExample
    {
        public void main()
        {

            // Configure OAuth2 access token for authorization: common
            Configuration.Default.AccessToken = "YOUR_ACCESS_TOKEN";

            var apiInstance = new WineApi();
            var wineId = 789;  // long? | Identificator of wine.
            var body = new Wine(); // Wine | Request body __SHOULD__ contain only fields with new values. _Fields_ parameter __SHOULD__ contain same fields as request body. (optional) 
            var fields = new List<string>(); // List<string> | Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value. (optional) 

            try
            {
                // Update information about wine
                Wine result = apiInstance.UpdateWine(wineId, body, fields);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling WineApi.UpdateWine: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **wineId** | **long?**| Identificator of wine. | 
 **body** | [**Wine**](Wine.md)| Request body __SHOULD__ contain only fields with new values. _Fields_ parameter __SHOULD__ contain same fields as request body. | [optional] 
 **fields** | [**List<string>**](string.md)| Specifies fields shoud be returned by server. Represents JSON paths separated by spaces. If not defined, server will return all fields, otherwise only fields indicated in parameter. Wrong values will be ignored.  NOTE: This parameter takes effect for successful responses only.  WARNING: Server will apply field filter even if it has wrong value. | [optional] 

### Return type

[**Wine**](Wine.md)

### Authorization

[common](../README.md#common)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

